@@ -68,6 +68,9 @@ char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_arrange_top( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt );
 char	*menu_auto_mark_arrange( long n, long d );
+bool_t	arrange_auto_mark( long n, long d );
+bool_t	arrange_auto_mark_mbr( long ls_mbr_n, long d );
+bool_t	remove_auto_mark_mbr( long ls_mbr_n );
 char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
