@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu-tab.h,v 1.10 2006/09/20 04:39:27 bowkenken Exp $
+* $Id: amenu-tab.h,v 1.14 2007/05/11 00:42:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_TAB_H
@@ -33,7 +33,9 @@
 
 /* ưޡ˥塼 */
 
-static menu_t	ls_menu_auto_mark[1 + 1 + ((1 + 7) * AUTO_MARK_MAX_N) + 1];
+static menu_t	ls_menu_auto_mark
+		[1 + 1 + (10 * AUTO_MARK_MAX_N)
+		+ (2 * AUTO_MARK_PAGE_N) + 2];
 
 static menu_t	ls_menu_appoint_item
 		[1 + 1 + (AUTO_MARK_APPOINT_ITEM_MAX_N * 2) + 1];
@@ -367,6 +369,42 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_OWN,
 		FLG_NULL,
 	},
+	{
+		"/edit/condition/hp min",
+		"<Item>",
+		'W',
+		"",
+		N_MSG_MENU_AUTO_MARK_COND_HP_MIN, "",
+		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_HP_MIN,
+		FLG_NULL,
+	},
+	{
+		"/edit/condition/hp max",
+		"<Item>",
+		'X',
+		"",
+		N_MSG_MENU_AUTO_MARK_COND_HP_MAX, "",
+		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_HP_MAX,
+		FLG_NULL,
+	},
+	{
+		"/edit/condition/mp min",
+		"<Item>",
+		'Y',
+		"",
+		N_MSG_MENU_AUTO_MARK_COND_MP_MIN, "",
+		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_MP_MIN,
+		FLG_NULL,
+	},
+	{
+		"/edit/condition/mp max",
+		"<Item>",
+		'Z',
+		"",
+		N_MSG_MENU_AUTO_MARK_COND_MP_MAX, "",
+		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_MP_MAX,
+		FLG_NULL,
+	},
 /* Appoint Item */
 	{
 		"/edit/appoint item",
