@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.40 2007/06/07 16:38:53 bowkenken Exp $
+* $Id: call.cpp,v 1.61 2007/12/24 16:36:54 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -43,19 +43,33 @@ extern WSCwindow *StatWin;
 
 bool_t	call_game_thread_create( void *(*func)( void * ) )
 {
-#ifdef D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( GameThreadCreate( func ) )
 		return TRUE;
 	else
 		return FALSE;
-#endif // D_WS
+#endif
 
-#ifdef D_GTK
-	if( GameThreadCreate( func ) )
+	return TRUE;
+}
+
+/***************************************************************
+* ᥤ󡦥롼פΥåɤλ
+* void *(*func)( void * ) : 롦Хåؿ
+* long code : λ
+* return : 顼̵ä
+***************************************************************/
+
+bool_t	call_game_thread_exit(
+	void *(*func)( void * ), long code
+)
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( GameThreadExit( func, code ) )
 		return TRUE;
 	else
 		return FALSE;
-#endif // D_GTK
+#endif
 
 	return TRUE;
 }
@@ -124,6 +138,15 @@ void	call_gui_menu_draw( draw_menu_t *data )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiMenu.draw( data );
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -158,6 +181,15 @@ void	call_gui_menu_wipe( void )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiMenu.wipe();
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -217,6 +249,15 @@ void	call_gui_message_set_flag_more( bool_t flag )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiMessage.setFlagMore( (bool)(flag != FALSE) );
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -252,6 +293,16 @@ void	call_gui_message_draw( void )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiMessage.draw( false );
+	gGuiMessage.drawScrollBar();
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -286,6 +337,15 @@ void	call_gui_num_draw( long *n, long min, long max, long figure )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiNum.draw( n, min, max, figure );
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -320,6 +380,15 @@ void	call_gui_num_wipe( void )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiNum.wipe();
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -351,11 +420,23 @@ void	call_gui_input_string_draw(
 
 	gdk_threads_enter();
 
+#if 0
+//@@@
 	gGuiInpStr.draw( ttl, str, len );
+#endif
 
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiInpStr.draw( ttl, str, len );
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -385,26 +466,107 @@ void	call_gui_input_string_wipe( void )
 
 	gdk_threads_enter();
 
+#if 0
+//@@@
 	gGuiInpStr.wipe();
+#endif
 
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiInpStr.wipe();
+#endif // D_MFC
 }
 
 /***************************************************************
 * եåǥ쥯ȥ
+* char *dir : եåǥ쥯ȥ
 ***************************************************************/
 
 void	set_str_dir_sel_graph( char *dir )
 {
-#ifdef D_WS
-	setStrDirSelGraph( dir );
-#endif // D_WS
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	FileList::setStrDirSelGraph( dir );
+#endif
+}
 
-#ifdef D_GTK
-	setStrDirSelGraph( dir );
-#endif // D_GTK
+/***************************************************************
+* եåΥ֥å򳫻
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	call_sel_conf_eval_block_begin( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( gSelConf.evalBlockBegin() )
+		return TRUE;
+	else
+		return FALSE;
+#endif
+
+	return TRUE;
+}
+
+/***************************************************************
+* եåΥ֥åλ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	call_sel_conf_eval_block_end( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( gSelConf.evalBlockEnd() )
+		return TRUE;
+	else
+		return FALSE;
+#endif
+
+	return TRUE;
+}
+
+/***************************************************************
+* եåοͤ
+* long token : ȡ
+* long n : 
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	call_sel_conf_eval_set_num( long token, long n )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( gSelConf.evalSetNum( (GraphConfToken)token, n ) )
+		return TRUE;
+	else
+		return FALSE;
+#endif
+
+	return TRUE;
+}
+
+/***************************************************************
+* եåʸ
+* long token : ȡ
+* WSCstring str : ʸ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	call_sel_conf_eval_set_str( long token, char *str )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( gSelConf.evalSetStr( (GraphConfToken)token, str ) )
+		return TRUE;
+	else
+		return FALSE;
+#endif
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -427,11 +589,8 @@ void	call_pcg_dun_reset( void )
 #endif // D_WS
 
 #ifdef D_GTK
-#if 0
-//@@@
 	if( !g_flg_init )
 		return;
-#endif
 	if( !g_flg_gui )
 		return;
 
@@ -442,13 +601,25 @@ void	call_pcg_dun_reset( void )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	TRY {
+		gPcgDun.reset();
+	} CATCH( CException, e ){
+	} END_CATCH
+#endif // D_MFC
 }
 
 /***************************************************************
-* ޥåפιե饰Υꥻå
+* Υޥåפ
 ***************************************************************/
 
-void	call_pcg_dun_reset_update_flg( void )
+void	call_pcg_dun_draw_turn( void )
 {
 #ifdef D_WS
 	if( !g_flg_init )
@@ -458,7 +629,7 @@ void	call_pcg_dun_reset_update_flg( void )
 
 	WSGIappDev()->lock();
 
-	gPcgDun.resetUpdateFlg();
+	gPcgDun.drawTurn();
 
 	WSGIappDev()->unlock();
 #endif // D_WS
@@ -471,11 +642,75 @@ void	call_pcg_dun_reset_update_flg( void )
 
 	gdk_threads_enter();
 
-	gPcgDun.resetUpdateFlg();
+	gPcgDun.drawTurn();
 
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	TRY {
+		gPcgDun.drawTurn();
+	} CATCH( CException, e ){
+	} END_CATCH
+#endif // D_MFC
+}
+
+/***************************************************************
+* ޥåפκ
+***************************************************************/
+
+void	call_pcg_dun_redraw( bool_t flgForce )
+{
+	bool bFlagForce;
+	if( flgForce )
+		bFlagForce = true;
+	else
+		bFlagForce = false;
+
+#ifdef D_WS
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	WSGIappDev()->lock();
+
+	gPcgDun.redraw( bFlagForce );
+
+	WSGIappDev()->unlock();
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gPcgDun.redraw( bFlagForce );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	TRY {
+		gPcgDun.redraw( bFlagForce );
+	} CATCH( CException, e ){
+	} END_CATCH
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -484,10 +719,21 @@ void	call_pcg_dun_reset_update_flg( void )
 * long map_y : ޥåפ Y ɸ
 * long map_w : ޥåפ
 * long map_h : ޥåפι⤵
+* bool_t flagForce : 
 ***************************************************************/
 
-void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h )
+void	call_pcg_dun_draw(
+	long map_x, long map_y,
+	long map_w, long map_h,
+	bool_t flagForce
+)
 {
+	bool bFlagForce;
+	if( flagForce )
+		bFlagForce = true;
+	else
+		bFlagForce = false;
+
 #ifdef D_WS
 	if( !g_flg_init )
 		return;
@@ -496,7 +742,7 @@ void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h )
 
 	WSGIappDev()->lock();
 
-	gPcgDun.draw( map_x, map_y, map_w, map_h );
+	gPcgDun.draw( map_x, map_y, map_w, map_h, bFlagForce );
 
 	WSGIappDev()->unlock();
 #endif // D_WS
@@ -509,11 +755,23 @@ void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h )
 
 	gdk_threads_enter();
 
-	gPcgDun.draw( map_x, map_y, map_w, map_h );
+	gPcgDun.draw( map_x, map_y, map_w, map_h, bFlagForce );
 
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	TRY {
+		gPcgDun.draw( map_x, map_y, map_w, map_h, bFlagForce );
+	} CATCH( CException, e ){
+	} END_CATCH
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -550,6 +808,18 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	TRY {
+		gPcgDun.scrollTile( map_x, map_y );
+	} CATCH( CException, e ){
+	} END_CATCH
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -560,10 +830,16 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 {
+	bool bFlagPre;
+	if( flagPre )
+		bFlagPre = true;
+	else
+		bFlagPre = false;
+
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeX();
 
 	return n;
@@ -572,12 +848,21 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeX();
 
 	return n;
 #endif // D_GTK
 
+#ifdef D_MFC
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, bFlagPre );
+	n = n / gPcgDun.getTileSizeX();
+
+	return n;
+#endif // D_MFC
+
 	if( flagPre )
 		return get_chr_left( chr->pre_draw_x, chr->dx );
 	else
@@ -592,10 +877,16 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 {
+	bool bFlagPre;
+	if( flagPre )
+		bFlagPre = true;
+	else
+		bFlagPre = false;
+
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawRight( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
 	return n;
@@ -604,12 +895,21 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawRight( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
 	return n;
 #endif // D_GTK
 
+#ifdef D_MFC
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, bFlagPre );
+	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
+
+	return n;
+#endif // D_MFC
+
 	if( flagPre )
 		return get_chr_right( chr->pre_draw_x, chr->dx );
 	else
@@ -624,10 +924,16 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 {
+	bool bFlagPre;
+	if( flagPre )
+		bFlagPre = true;
+	else
+		bFlagPre = false;
+
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawTop( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeY();
 
 	return n;
@@ -636,12 +942,21 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawTop( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
 	n = n / gPcgDun.getTileSizeY();
 
 	return n;
 #endif // D_GTK
 
+#ifdef D_MFC
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, bFlagPre );
+	n = n / gPcgDun.getTileSizeY();
+
+	return n;
+#endif // D_MFC
+
 	if( flagPre )
 		return get_chr_top( chr->pre_draw_y, chr->dy );
 	else
@@ -656,10 +971,16 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 {
+	bool bFlagPre;
+	if( flagPre )
+		bFlagPre = true;
+	else
+		bFlagPre = false;
+
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
 	return n;
@@ -668,12 +989,21 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flagPre );
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
 	return n;
 #endif // D_GTK
 
+#ifdef D_MFC
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, bFlagPre );
+	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
+
+	return n;
+#endif // D_MFC
+
 	if( flagPre )
 		return get_chr_bottom( chr->pre_draw_y, chr->dy );
 	else
@@ -693,6 +1023,10 @@ bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
 	return gPcgDun.clipWin( mapX, mapY );
 #endif // D_GTK
 
+#ifdef D_MFC
+	return gPcgDun.clipWin( mapX, mapY );
+#endif // D_MFC
+
 	return true;
 }
 
@@ -708,6 +1042,10 @@ bool_t	call_pcg_dun_clip_win_x( long mapX )
 	return gPcgDun.clipWinX( mapX );
 #endif // D_GTK
 
+#ifdef D_MFC
+	return gPcgDun.clipWinX( mapX );
+#endif // D_MFC
+
 	return true;
 }
 
@@ -723,6 +1061,10 @@ bool_t	call_pcg_dun_clip_win_y( long mapY )
 	return gPcgDun.clipWinY( mapY );
 #endif // D_GTK
 
+#ifdef D_MFC
+	return gPcgDun.clipWinY( mapY );
+#endif // D_MFC
+
 	return true;
 }
 
@@ -730,7 +1072,7 @@ bool_t	call_pcg_dun_clip_win_y( long mapY )
 * ơɥ
 ***************************************************************/
 
-void	call_stat_win_redraw( void )
+void	call_gui_stat_redraw( void )
 {
 #ifdef D_WS
 	if( !g_flg_init )
@@ -758,6 +1100,59 @@ void	call_stat_win_redraw( void )
 	gdk_flush();
 	gdk_threads_leave();
 #endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiStat.redraw();
+#endif // D_MFC
+}
+
+/***************************************************************
+* ơɥ
+* long n : СNo.
+***************************************************************/
+
+void	call_gui_stat_draw( long n )
+{
+#ifdef D_WS
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	WSGIappDev()->lock();
+
+	StatWin->draw( n );
+
+	WSGIappDev()->unlock();
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiStat.draw( n );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+
+#ifdef D_MFC
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gGuiStat.draw( n );
+#endif // D_MFC
 }
 
 /***************************************************************
@@ -796,5 +1191,14 @@ long	call_key_get_char( void )
 	gdk_threads_leave();
 #endif // D_GTK
 
+#ifdef D_MFC
+	if( !g_flg_init )
+		return c;
+	if( !g_flg_gui )
+		return c;
+
+	c = gKey.getChar();
+#endif // D_MFC
+
 	return c;
 }
