@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.106 2007/03/18 03:06:32 bowkenken Exp $
+* $Id: chr.h,v 1.107 2007/06/11 05:56:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -800,6 +800,9 @@ typedef struct chr_t {
 	/* 󥹥ǡơ֥ */
 	mnstr_tab_t	*mnstr_tab, *mnstr_tab_org;
 
+	/* ڥåȤɤ */
+	bool_t	flg_pet;
+
 	/* ¾ */
 	chr_work_t	work;
 
