@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.71 2007/02/04 23:09:23 bowkenken Exp $
+* $Id: curs.c,v 1.72 2007/11/09 06:49:38 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -673,6 +673,15 @@ void	curs_noraw( void )
 
 void	curs_move( int scrn_y, int scrn_x )
 {
+	if( scrn_x < SCREEN_MIN_X )
+		return;
+	if( scrn_x > SCREEN_MAX_X )
+		return;
+	if( scrn_y < SCREEN_MIN_Y )
+		return;
+	if( scrn_y > get_max_line() - 1 )
+		return;
+
 #ifndef	D_DOS
 	if( !chk_curs_draw() )
 		return;
