@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.14 2007/02/02 19:45:13 bowkenken Exp $
+* $Id: draw-tab.h,v 1.16 2007/03/11 20:49:58 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_TAB_H
@@ -83,7 +83,7 @@
 
 #define	WIN_MBR_DATA_DRAW_MID_X	41
 
-/* page 1/2 */
+/* page 1/4 */
 
 #define	WIN_MBR_DATA_NAME_TTL_DRAW_MIN_X	0
 #define	WIN_MBR_DATA_NAME_TTL_DRAW_MIN_Y	0
@@ -270,7 +270,7 @@
 #define	WIN_MBR_DATA_STORE_LIGHT_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 11 + 1)
 
-/* page 2/2 */
+/* page 2/4 */
 
 /* lev left */
 
@@ -474,8 +474,17 @@
 #define	WIN_MBR_DATA_NIN_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y + 12)
 
+/* page 3/4 4/4 */
+
+#define	WIN_MBR_DATA_ITEM_DRAW_MIN_X	\
+		WIN_MBR_DATA_NAME_TTL_DRAW_MIN_X
+#define	WIN_MBR_DATA_ITEM_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_NAME_TTL_DRAW_MIN_Y + 1)
+
 /* Page */
 
+#define	WIN_MBR_DATA_PREV_PAGE_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
+#define	WIN_MBR_DATA_PREV_PAGE_DRAW_MIN_Y	18
 #define	WIN_MBR_DATA_NEXT_PAGE_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
 #define	WIN_MBR_DATA_NEXT_PAGE_DRAW_MIN_Y	19
 
@@ -513,6 +522,16 @@
 
 /***************************************************************/
 
+
+/* Сǡβ̤򺸱˽Ƕڤ뤫? */
+
+bool_t	flg_mbr_data_draw_v_line[MBR_DATA_PAGE_MAX_N] = {
+	TRUE,
+	TRUE,
+	FALSE,
+	FALSE,
+};
+
 /* СǡΥǥݥȽ */
 
 bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
@@ -614,6 +633,38 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
+		TRUE,	/* DATA_N_ITEM_00, */
+		TRUE,	/* DATA_N_ITEM_01, */
+		TRUE,	/* DATA_N_ITEM_02, */
+		TRUE,	/* DATA_N_ITEM_03, */
+		TRUE,	/* DATA_N_ITEM_04, */
+		TRUE,	/* DATA_N_ITEM_05, */
+		TRUE,	/* DATA_N_ITEM_06, */
+		TRUE,	/* DATA_N_ITEM_07, */
+		TRUE,	/* DATA_N_ITEM_08, */
+		TRUE,	/* DATA_N_ITEM_09, */
+		TRUE,	/* DATA_N_ITEM_10, */
+		TRUE,	/* DATA_N_ITEM_11, */
+		TRUE,	/* DATA_N_ITEM_12, */
+		TRUE,	/* DATA_N_ITEM_13, */
+		TRUE,	/* DATA_N_ITEM_14, */
+		TRUE,	/* DATA_N_ITEM_15, */
+
+		TRUE,	/* DATA_N_EQUIP_WIELDING, */
+		TRUE,	/* DATA_N_EQUIP_SHIELD, */
+		TRUE,	/* DATA_N_EQUIP_BOW, */
+		TRUE,	/* DATA_N_EQUIP_ARW, */
+		TRUE,	/* DATA_N_EQUIP_HEAD, */
+		TRUE,	/* DATA_N_EQUIP_NECK, */
+		TRUE,	/* DATA_N_EQUIP_BODY, */
+		TRUE,	/* DATA_N_EQUIP_ABOUT_BODY, */
+		TRUE,	/* DATA_N_EQUIP_ARM, */
+		TRUE,	/* DATA_N_EQUIP_RIGHT_HAND, */
+		TRUE,	/* DATA_N_EQUIP_LEFT_HAND, */
+		TRUE,	/* DATA_N_EQUIP_FEET, */
+		TRUE,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
+
+		TRUE,	/* DATA_N_PREV_PAGE, */
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
 	{
@@ -714,6 +765,38 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
+		TRUE,	/* DATA_N_ITEM_00, */
+		TRUE,	/* DATA_N_ITEM_01, */
+		TRUE,	/* DATA_N_ITEM_02, */
+		TRUE,	/* DATA_N_ITEM_03, */
+		TRUE,	/* DATA_N_ITEM_04, */
+		TRUE,	/* DATA_N_ITEM_05, */
+		TRUE,	/* DATA_N_ITEM_06, */
+		TRUE,	/* DATA_N_ITEM_07, */
+		TRUE,	/* DATA_N_ITEM_08, */
+		TRUE,	/* DATA_N_ITEM_09, */
+		TRUE,	/* DATA_N_ITEM_10, */
+		TRUE,	/* DATA_N_ITEM_11, */
+		TRUE,	/* DATA_N_ITEM_12, */
+		TRUE,	/* DATA_N_ITEM_13, */
+		TRUE,	/* DATA_N_ITEM_14, */
+		TRUE,	/* DATA_N_ITEM_15, */
+
+		TRUE,	/* DATA_N_EQUIP_WIELDING, */
+		TRUE,	/* DATA_N_EQUIP_SHIELD, */
+		TRUE,	/* DATA_N_EQUIP_BOW, */
+		TRUE,	/* DATA_N_EQUIP_ARW, */
+		TRUE,	/* DATA_N_EQUIP_HEAD, */
+		TRUE,	/* DATA_N_EQUIP_NECK, */
+		TRUE,	/* DATA_N_EQUIP_BODY, */
+		TRUE,	/* DATA_N_EQUIP_ABOUT_BODY, */
+		TRUE,	/* DATA_N_EQUIP_ARM, */
+		TRUE,	/* DATA_N_EQUIP_RIGHT_HAND, */
+		TRUE,	/* DATA_N_EQUIP_LEFT_HAND, */
+		TRUE,	/* DATA_N_EQUIP_FEET, */
+		TRUE,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
+
+		TRUE,	/* DATA_N_PREV_PAGE, */
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
 	{
@@ -814,110 +897,172 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
+		TRUE,	/* DATA_N_ITEM_00, */
+		TRUE,	/* DATA_N_ITEM_01, */
+		TRUE,	/* DATA_N_ITEM_02, */
+		TRUE,	/* DATA_N_ITEM_03, */
+		TRUE,	/* DATA_N_ITEM_04, */
+		TRUE,	/* DATA_N_ITEM_05, */
+		TRUE,	/* DATA_N_ITEM_06, */
+		TRUE,	/* DATA_N_ITEM_07, */
+		TRUE,	/* DATA_N_ITEM_08, */
+		TRUE,	/* DATA_N_ITEM_09, */
+		TRUE,	/* DATA_N_ITEM_10, */
+		TRUE,	/* DATA_N_ITEM_11, */
+		TRUE,	/* DATA_N_ITEM_12, */
+		TRUE,	/* DATA_N_ITEM_13, */
+		TRUE,	/* DATA_N_ITEM_14, */
+		TRUE,	/* DATA_N_ITEM_15, */
+
+		TRUE,	/* DATA_N_EQUIP_WIELDING, */
+		TRUE,	/* DATA_N_EQUIP_SHIELD, */
+		TRUE,	/* DATA_N_EQUIP_BOW, */
+		TRUE,	/* DATA_N_EQUIP_ARW, */
+		TRUE,	/* DATA_N_EQUIP_HEAD, */
+		TRUE,	/* DATA_N_EQUIP_NECK, */
+		TRUE,	/* DATA_N_EQUIP_BODY, */
+		TRUE,	/* DATA_N_EQUIP_ABOUT_BODY, */
+		TRUE,	/* DATA_N_EQUIP_ARM, */
+		TRUE,	/* DATA_N_EQUIP_RIGHT_HAND, */
+		TRUE,	/* DATA_N_EQUIP_LEFT_HAND, */
+		TRUE,	/* DATA_N_EQUIP_FEET, */
+		TRUE,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
+
+		TRUE,	/* DATA_N_PREV_PAGE, */
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
 };
 
 /* СΥǡɽڡֹ */
 
-#define	DATA_PAGE_N_ALL	127
-
 long	data_page_n_tab[] = {
 	0,	/* DATA_N_NULL, */
 
-	DATA_PAGE_N_ALL,	/* DATA_N_NAME, */
-	0,	/* DATA_N_FACE, */
-	0,	/* DATA_N_RACE_STR, */
-	0,	/* DATA_N_RACE_NAME, */
-	0,	/* DATA_N_SEX, */
+	0xff,	/* DATA_N_NAME, */
+	0x01,	/* DATA_N_FACE, */
+	0x01,	/* DATA_N_RACE_STR, */
+	0x01,	/* DATA_N_RACE_NAME, */
+	0x01,	/* DATA_N_SEX, */
 
-	0,	/* DATA_N_HP_VAL, */
-	0,	/* DATA_N_MP_VAL, */
+	0x01,	/* DATA_N_HP_VAL, */
+	0x01,	/* DATA_N_MP_VAL, */
 
-	0,	/* DATA_N_VAL_TTL, */
-	0,	/* DATA_N_HIT, */
-	0,	/* DATA_N_WPN_CRTCL, */
-	0,	/* DATA_N_DAM, */
-	0,	/* DATA_N_DEF, */
-	0,	/* DATA_N_ARMOR_CRTCL, */
-	0,	/* DATA_N_AC, */
-	0,	/* DATA_N_GOLD, */
-	0,	/* DATA_N_TURN, */
+	0x01,	/* DATA_N_VAL_TTL, */
+	0x01,	/* DATA_N_HIT, */
+	0x01,	/* DATA_N_WPN_CRTCL, */
+	0x01,	/* DATA_N_DAM, */
+	0x01,	/* DATA_N_DEF, */
+	0x01,	/* DATA_N_ARMOR_CRTCL, */
+	0x01,	/* DATA_N_AC, */
+	0x01,	/* DATA_N_GOLD, */
+	0x01,	/* DATA_N_TURN, */
 
-	0,	/* DATA_N_STAT_TTL, */
-	0,	/* DATA_N_STAT_DEAD, */
-	0,	/* DATA_N_STAT_STONE, */
-	0,	/* DATA_N_STAT_PARALYZE, */
-	0,	/* DATA_N_STAT_POISON, */
-	0,	/* DATA_N_STAT_CONFUSION, */
-	0,	/* DATA_N_STAT_BLIND, */
-	0,	/* DATA_N_STAT_SLEEP, */
-	0,	/* DATA_N_STAT_SILENCE, */
-	0,	/* DATA_N_STAT_CAUGHT, */
-	0,	/* DATA_N_STAT_FEAR, */
-	0,	/* DATA_N_STAT_HALLUCINATION, */
-	0,	/* DATA_N_STAT_CHARM, */
-	0,	/* DATA_N_STAT_FLY, */
-	0,	/* DATA_N_STAT_HUNGRY, */
-	0,	/* DATA_N_STAT_FAINT, */
-	0,	/* DATA_N_STAT_DRUNK, */
-	0,	/* DATA_N_STAT_VANISH, */
-	0,	/* DATA_N_STAT_IRON_BODY, */
-	0,	/* DATA_N_STAT_PASSWALL, */
-	0,	/* DATA_N_STAT_SENSE_INVISIBLE, */
+	0x01,	/* DATA_N_STAT_TTL, */
+	0x01,	/* DATA_N_STAT_DEAD, */
+	0x01,	/* DATA_N_STAT_STONE, */
+	0x01,	/* DATA_N_STAT_PARALYZE, */
+	0x01,	/* DATA_N_STAT_POISON, */
+	0x01,	/* DATA_N_STAT_CONFUSION, */
+	0x01,	/* DATA_N_STAT_BLIND, */
+	0x01,	/* DATA_N_STAT_SLEEP, */
+	0x01,	/* DATA_N_STAT_SILENCE, */
+	0x01,	/* DATA_N_STAT_CAUGHT, */
+	0x01,	/* DATA_N_STAT_FEAR, */
+	0x01,	/* DATA_N_STAT_HALLUCINATION, */
+	0x01,	/* DATA_N_STAT_CHARM, */
+	0x01,	/* DATA_N_STAT_FLY, */
+	0x01,	/* DATA_N_STAT_HUNGRY, */
+	0x01,	/* DATA_N_STAT_FAINT, */
+	0x01,	/* DATA_N_STAT_DRUNK, */
+	0x01,	/* DATA_N_STAT_VANISH, */
+	0x01,	/* DATA_N_STAT_IRON_BODY, */
+	0x01,	/* DATA_N_STAT_PASSWALL, */
+	0x01,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
-	0,	/* DATA_N_STORE_LIGHT, */
+	0x01,	/* DATA_N_STORE_LIGHT, */
 
-	1,	/* DATA_N_LEV_LEFT, */
-	1,	/* DATA_N_EXP_LEFT, */
-	1,	/* DATA_N_NEED_EXP_LEFT, */
+	0x02,	/* DATA_N_LEV_LEFT, */
+	0x02,	/* DATA_N_EXP_LEFT, */
+	0x02,	/* DATA_N_NEED_EXP_LEFT, */
 
-	1,	/* DATA_N_LEV_RIGHT, */
-	1,	/* DATA_N_EXP_RIGHT, */
-	1,	/* DATA_N_NEED_EXP_RIGHT, */
+	0x02,	/* DATA_N_LEV_RIGHT, */
+	0x02,	/* DATA_N_EXP_RIGHT, */
+	0x02,	/* DATA_N_NEED_EXP_RIGHT, */
 
-	1,	/* DATA_N_HP, */
-	1,	/* DATA_N_MP, */
-	1,	/* DATA_N_DEX, */
-	1,	/* DATA_N_STR, */
-	1,	/* DATA_N_AGI, */
-	1,	/* DATA_N_INT, */
-	1,	/* DATA_N_WIS, */
-	1,	/* DATA_N_CHA, */
+	0x02,	/* DATA_N_HP, */
+	0x02,	/* DATA_N_MP, */
+	0x02,	/* DATA_N_DEX, */
+	0x02,	/* DATA_N_STR, */
+	0x02,	/* DATA_N_AGI, */
+	0x02,	/* DATA_N_INT, */
+	0x02,	/* DATA_N_WIS, */
+	0x02,	/* DATA_N_CHA, */
 
-	1,	/* DATA_N_RESI_TTL, */
-	1,	/* DATA_N_RESI_TTL_LAWFUL, */
-	1,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
-	1,	/* DATA_N_RESI_TTL_CHAOTIC, */
-	1,	/* DATA_N_RESI_TTL_GOOD, */
-	1,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
-	1,	/* DATA_N_RESI_TTL_EVIL, */
-	1,	/* DATA_N_RESI_KNOC, */
-	1,	/* DATA_N_RESI_SLAS, */
-	1,	/* DATA_N_RESI_STIN, */
-	1,	/* DATA_N_RESI_HEAT, */
-	1,	/* DATA_N_RESI_COLD, */
-	1,	/* DATA_N_RESI_MIND, */
-	1,	/* DATA_N_RESI_ACID, */
-	1,	/* DATA_N_RESI_ELEC, */
-	1,	/* DATA_N_RESI_POIS, */
+	0x02,	/* DATA_N_RESI_TTL, */
+	0x02,	/* DATA_N_RESI_TTL_LAWFUL, */
+	0x02,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
+	0x02,	/* DATA_N_RESI_TTL_CHAOTIC, */
+	0x02,	/* DATA_N_RESI_TTL_GOOD, */
+	0x02,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
+	0x02,	/* DATA_N_RESI_TTL_EVIL, */
+	0x02,	/* DATA_N_RESI_KNOC, */
+	0x02,	/* DATA_N_RESI_SLAS, */
+	0x02,	/* DATA_N_RESI_STIN, */
+	0x02,	/* DATA_N_RESI_HEAT, */
+	0x02,	/* DATA_N_RESI_COLD, */
+	0x02,	/* DATA_N_RESI_MIND, */
+	0x02,	/* DATA_N_RESI_ACID, */
+	0x02,	/* DATA_N_RESI_ELEC, */
+	0x02,	/* DATA_N_RESI_POIS, */
 
-	1,	/* DATA_N_CLASS, */
+	0x02,	/* DATA_N_CLASS, */
 
-	1,	/* DATA_N_FIG, */
-	1,	/* DATA_N_MON, */
-	1,	/* DATA_N_HUN, */
-	1,	/* DATA_N_THI, */
-	1,	/* DATA_N_MAG, */
-	1,	/* DATA_N_SOR, */
-	1,	/* DATA_N_ENC, */
-	1,	/* DATA_N_SUM, */
-	1,	/* DATA_N_PRI, */
-	1,	/* DATA_N_SHA, */
-	1,	/* DATA_N_BAR, */
-	1,	/* DATA_N_NIN, */
+	0x02,	/* DATA_N_FIG, */
+	0x02,	/* DATA_N_MON, */
+	0x02,	/* DATA_N_HUN, */
+	0x02,	/* DATA_N_THI, */
+	0x02,	/* DATA_N_MAG, */
+	0x02,	/* DATA_N_SOR, */
+	0x02,	/* DATA_N_ENC, */
+	0x02,	/* DATA_N_SUM, */
+	0x02,	/* DATA_N_PRI, */
+	0x02,	/* DATA_N_SHA, */
+	0x02,	/* DATA_N_BAR, */
+	0x02,	/* DATA_N_NIN, */
 
-	DATA_PAGE_N_ALL,	/* DATA_N_NEXT_PAGE, */
+	0x04,	/* DATA_N_ITEM_00, */
+	0x04,	/* DATA_N_ITEM_01, */
+	0x04,	/* DATA_N_ITEM_02 */
+	0x04,	/* DATA_N_ITEM_03, */
+	0x04,	/* DATA_N_ITEM_04 */
+	0x04,	/* DATA_N_ITEM_05, */
+	0x04,	/* DATA_N_ITEM_06, */
+	0x04,	/* DATA_N_ITEM_07, */
+	0x04,	/* DATA_N_ITEM_08, */
+	0x04,	/* DATA_N_ITEM_09, */
+	0x04,	/* DATA_N_ITEM_10, */
+	0x04,	/* DATA_N_ITEM_11, */
+	0x04,	/* DATA_N_ITEM_12 */
+	0x04,	/* DATA_N_ITEM_13, */
+	0x04,	/* DATA_N_ITEM_14 */
+	0x04,	/* DATA_N_ITEM_15, */
+
+	0x08,	/* DATA_N_EQUIP_WIELDING, */
+	0x08,	/* DATA_N_EQUIP_SHIELD, */
+	0x08,	/* DATA_N_EQUIP_BOW, */
+	0x08,	/* DATA_N_EQUIP_ARW, */
+	0x08,	/* DATA_N_EQUIP_HEAD, */
+	0x08,	/* DATA_N_EQUIP_NECK, */
+	0x08,	/* DATA_N_EQUIP_BODY, */
+	0x08,	/* DATA_N_EQUIP_ABOUT_BODY, */
+	0x08,	/* DATA_N_EQUIP_ARM, */
+	0x08,	/* DATA_N_EQUIP_RIGHT_HAND, */
+	0x08,	/* DATA_N_EQUIP_LEFT_HAND, */
+	0x08,	/* DATA_N_EQUIP_FEET, */
+	0x08,	/* DATA_N_EQUIP_LIGHT_SOURCE, */
+
+	0xff,	/* DATA_N_PREV_PAGE, */
+	0xff,	/* DATA_N_NEXT_PAGE, */
 };
 
 /* § */
