@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.106 2007/06/07 02:29:25 bowkenken Exp $
+* $Id: dun.c,v 1.108 2007/06/12 07:40:53 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -411,8 +411,8 @@ void	reset_all( bool_t flg_appear )
 
 	bgn_nest_flg( g_nest_flg_dun );
 
+	garbage_collection_all_item();
 	reset_trap();
-	clr_dun_item();
 	reset_mnstr();
 	release_all_mbr();
 
@@ -2367,7 +2367,7 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 				continue;
 			} else if( chr_p == NULL ){
 				continue;
-			} else if( chr_p->kind == CHR_KIND_MBR ){
+			} else if( is_mbr( chr_p ) ){
 				mbr_t	*p;
 
 				/* Сä */
