@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.122 2007/05/20 15:54:43 bowkenken Exp $
+* $Id: fight.c,v 1.125 2007/06/11 23:20:57 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,17 +40,13 @@
 ***************************************************************/
 
 #if	1
-
 /* ٥뤬㤤ۤɶ */
 /* ٥뤬夬о夬ۤɺ̵ʤ */
-#define	FLG_ITEM_ADD_RATE	1
-
+# define	FLG_ITEM_ADD_RATE	1
 #else
-
 /* ٥뤬㤤Ϻ̵ */
 /* ٥뤬夬о夬ۤɶϤˤʤ */
-#define	FLG_ITEM_ADD_RATE	0
-
+# define	FLG_ITEM_ADD_RATE	0
 #endif
 
 /***************************************************************
@@ -58,55 +54,82 @@
 ***************************************************************/
 
 /* ¦䤹 */
-#define	HIT_ADJ_RATE	((rate_t)150)
 
-#define	HIT_FIT_AVE_N	10
-#define	HIT_HNT_AVE_N	10
-#define	WPN_CRTCL_FIT_AVE_N	20
-#define	WPN_CRTCL_HNT_AVE_N	20
-#define	DAM_FIT_AVE_N	10
-#define	DAM_HNT_AVE_N	10
+#define	HIT_ADJ_RATE	((rate_t)100)
 
-#define	HIT_MON_MUL	10
-#define	HIT_MON_ADD	0
-#define	DAM_MON_MUL	10
-#define	DAM_MON_ADD	0
-#define	DEF_MON_MUL	10
-#define	DEF_MON_ADD	0
+/* ǽϤʿ */
 
-/* դΥƥ롦ҥåΨ */
-#define	WPN_CRTCL_THF_LEV_RATE	((rate_t)30)
-#define	WPN_CRTCL_THF_MAX_RATE	((rate_t)30)
+#define	HIT_AVE_N	10
+#define	WPN_CRTCL_AVE_N	20
+#define	DAM_AVE_N	10
 
-/* ǦԤμڤΨ */
-#define	NINJA_CRTCL_RATE	((rate_t)150)
+/* ɸǽϤʿ */
 
-#define	DEF_MIN_RATE	((rate_t)30)
 #define	DEF_AVE_N	10
 #define	ARMOR_CRTCL_AVE_N	10
 #define	AC_AVE_N	20
 
+#define	DEF_MIN_RATE	((rate_t)30)
+
+/* ǽϤνΨ */
+
+#define	ADD_HIT_RATE	((rate_t)10)
+#define	ADD_WPN_CRTCL_RATE	((rate_t)10)
+#define	ADD_DAM_RATE	((rate_t)10)
+
+#define	TWO_HANDED_WPN_ADD_DAM_RATE	((rate_t)120)
+
+/* ɸǽϤνΨ */
+
+#define	ADD_DEF_RATE	((rate_t)10)
+#define	ADD_ARMOR_CRTCL_RATE	((rate_t)10)
+#define	ADD_AC_RATE	((rate_t)10)
+
+/* 󥯤Υ٥˴ */
+
+#define	HIT_MON_MUL	10
+#define	HIT_MON_ADD	20
+#define	DAM_MON_MUL	10
+#define	DAM_MON_ADD	20
+#define	DEF_MON_MUL	10
+#define	DEF_MON_ADD	20
+
+/* դΥƥ롦ҥåΨ */
+
+#define	WPN_CRTCL_THF_LEV_RATE	((rate_t)30)
+#define	WPN_CRTCL_THF_MAX_RATE	((rate_t)30)
+
+/* ǦԤμڤΨ */
+
+#define	NINJA_CRTCL_RATE	((rate_t)150)
+
 /* ɸ(⤷Ƥʤ)ɸϥåΨ */
+
 #define	DEF_DEF_RATE	((rate_t)150)
 #define	DEF_AC_RATE	((rate_t)150)
 
 /* ˡξι */
+
 #define	DAM_STICK_RATE	((rate_t)300)
 #define	DAM_STICK_ADD	10
 
 /* ʸι */
-#define	DAM_SPELL_RATE	((rate_t)300)
+
+#define	DAM_SPELL_RATE	((rate_t)200)
 #define	DAM_SPELL_ADD	10
 
 /* ֥Ȥɸ */
+
 #define	DOOR_DEF	12
 #define	TRAP_DEF	8
 #define	ITEM_DEF	6
 
 /* ֹϤεΥˤäƸΨ */
+
 #define	RATE_PER_RANGE	((rate_t)200)
 
 /* СƱΤηи */
+
 #define	TRAINING_EXP	1
 
 /***************************************************************
@@ -215,7 +238,7 @@ bool_t	set_attack_chr_bash(
 	chr_t *chr, attack_t *attack, long range, bool_t flg_ave
 )
 {
-	if( chr->kind == CHR_KIND_MBR )
+	if( is_mbr( chr ) )
 		return set_attack_mbr_bash( chr, attack, range, flg_ave );
 	if( chr->kind == CHR_KIND_MNSTR )
 		return set_attack_mnstr_bash( chr, attack, range, flg_ave );
@@ -244,7 +267,7 @@ bool_t	set_attack_mbr_bash(
 		return FALSE;
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	/* Υơ֥ */
@@ -276,7 +299,7 @@ bool_t	set_attack_mbr_bash(
 		attack->hit += add_hit( eq->dat.wpn.add_hit );
 		attack->crtcl += add_wpn_crtcl( eq->dat.wpn.add_crtcl );
 		attack->dam += add_dam( eq->dat.wpn.add_dam );
-		attack->dam += attack->dam
+		attack->dam = attack->dam
 				* add_dam_two_handed_wpn( mbr, eq )
 				/ _100_PERCENT;
 	}
@@ -375,7 +398,7 @@ bool_t	set_attack_chr_throw(
 	chr_t *chr, attack_t *attack, long range, bool_t flg_ave
 )
 {
-	if( chr->kind == CHR_KIND_MBR )
+	if( is_mbr( chr ) )
 		return set_attack_mbr_throw( chr, attack, range, flg_ave );
 	if( chr->kind == CHR_KIND_MNSTR )
 		return set_attack_mnstr_throw( chr, attack, range, flg_ave );
@@ -402,7 +425,7 @@ bool_t	set_attack_mbr_throw(
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 	if( attack == NULL )
 		return FALSE;
@@ -837,7 +860,7 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 			if( ((mnstr_t *)d_p)->mnstr_tab == NULL )
 				flg_d_null = TRUE;
 	}
-	if( o_p->kind == CHR_KIND_MBR )
+	if( is_mbr( o_p ) )
 		if( ((mbr_t *)o_p)->trgt.kind == TRGT_KIND_MNSTR_NULL )
 			flg_d_null = TRUE;
 
@@ -1281,7 +1304,7 @@ bool_t	spell_attack(
 	if( d_p == NULL ){
 		print_msg( FLG_MSG_ERR, MSG_ERR_MNSTR_NULL );
 
-		if( o_p->kind == CHR_KIND_MBR )
+		if( is_mbr( o_p ) )
 			clr_chr_trgt_act( (mbr_t *)o_p, FALSE );
 
 		return FALSE;
@@ -1487,7 +1510,7 @@ bool_t	chr_break_door( chr_t *chr, long dr_n )
 	hit += hit * chr->fx_data.bless;
 
 	if( DOOR_DEF > hit ){
-		if( chr->kind == CHR_KIND_MBR ){
+		if( is_mbr( chr ) ){
 			print_msg( FLG_MSG_ERR, MSG_ERR_DOOR_BREAK_LEV,
 					chr->name );
 		}
@@ -1497,7 +1520,7 @@ bool_t	chr_break_door( chr_t *chr, long dr_n )
 	if( !break_door( dr_n ) )
 		return FALSE;
 
-	if( chr->kind == CHR_KIND_MBR )
+	if( is_mbr( chr ) )
 		print_msg( FLG_NULL, MSG_DOOR_BREAK, chr->name );
 
 	return TRUE;
@@ -1604,7 +1627,7 @@ bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 	if( d_p == NULL )
 		return FALSE;
 
-	if( o_p->kind != CHR_KIND_MBR )
+	if( !is_mbr( o_p ) )
 		return FALSE;
 
 	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
@@ -1649,7 +1672,7 @@ bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 
 	if( !chk_flg( d_p->flg_chr, FLG_CHR_MAGIC_PROTECT ) )
 		return FALSE;
-	if( o_p->kind != CHR_KIND_MBR )
+	if( !is_mbr( o_p ) )
 		return FALSE;
 
 	do {
@@ -1712,8 +1735,8 @@ long	get_hit( chr_t *p, const attack_t *attack )
 		abl = ABL_KIND_FIG;
 
 	hit = 0;
-	hit += calc_lev_to_val( get_lev( p, ABL_KIND_DEX ), ABL_KIND_DEX );
-	hit += calc_lev_to_val( get_lev( p, abl ), abl );
+	hit += calc_abl_to_val( p, abl );
+	hit += calc_abl_to_val( p, ABL_KIND_DEX );
 	hit /= 2;
 
 	if( abl == ABL_KIND_MON ){
@@ -1725,16 +1748,16 @@ long	get_hit( chr_t *p, const attack_t *attack )
 			wpn_hit += HIT_MON_ADD;
 	}
 
-	if( p->kind == CHR_KIND_MBR )
+	if( is_mbr( p ) )
 		hit = hit * calc_rate_abl_equip( p, abl ) / _100_PERCENT;
 
 	/* FXͤä */
 
 	wpn_hit += p->fx_data.wpn_hit;
 
-#ifdef	FLG_ITEM_ADD_RATE
+#if	FLG_ITEM_ADD_RATE
 
-	hit += HIT_FIT_AVE_N * wpn_hit / _100_PERCENT;
+	hit += HIT_AVE_N * wpn_hit / _100_PERCENT;
 
 #else	/* FLG_ITEM_ADD_RATE */
 
@@ -1783,8 +1806,8 @@ long	get_dam( chr_t *p, const attack_t *attack )
 	}
 
 	dam = 0;
-	dam += calc_lev_to_val( get_lev( p, abl ), abl );
-	dam += calc_lev_to_val( get_lev( p, sub_abl ), sub_abl );
+	dam += calc_abl_to_val( p, abl );
+	dam += calc_abl_to_val( p, sub_abl );
 	dam /= 2;
 
 	if( abl == ABL_KIND_MON ){
@@ -1796,16 +1819,16 @@ long	get_dam( chr_t *p, const attack_t *attack )
 			wpn_dam += DAM_MON_ADD;
 	}
 
-	if( p->kind == CHR_KIND_MBR )
+	if( is_mbr( p ) )
 		dam = dam * calc_rate_abl_equip( p, abl ) / _100_PERCENT;
 
 	/* FXͤä */
 
 	wpn_dam += p->fx_data.wpn_dam;
 
-#ifdef	FLG_ITEM_ADD_RATE
+#if	FLG_ITEM_ADD_RATE
 
-	dam += DAM_FIT_AVE_N * wpn_dam / _100_PERCENT;
+	dam += DAM_AVE_N * wpn_dam / _100_PERCENT;
 
 #else	/* FLG_ITEM_ADD_RATE */
 
@@ -1839,11 +1862,11 @@ long	get_def( chr_t *p )
 	abl = get_def_abl( p );
 
 	def = 0;
-	def += calc_lev_to_val( get_lev( p, ABL_KIND_AGI ), ABL_KIND_AGI );
-	def += calc_lev_to_val( get_lev( p, abl ), abl );
+	def += calc_abl_to_val( p, abl );
+	def += calc_abl_to_val( p, ABL_KIND_AGI );
 	def /= 2;
 
-	if( p->kind == CHR_KIND_MBR )
+	if( is_mbr( p ) )
 		def = def * calc_rate_abl_equip( p, abl ) / _100_PERCENT;
 
 	armor_def = get_armor_def( p, abl );
@@ -1851,7 +1874,7 @@ long	get_def( chr_t *p )
 	if( armor_def < DEF_MIN_RATE )
 		armor_def = DEF_MIN_RATE;
 
-#ifdef	FLG_ITEM_ADD_RATE
+#if	FLG_ITEM_ADD_RATE
 
 	def += DEF_AVE_N * armor_def / _100_PERCENT;
 
@@ -1878,7 +1901,7 @@ abl_kind_t	get_def_abl( chr_t *p )
 	if( p == NULL )
 		return ABL_KIND_FIG;
 
-	if( p->kind == CHR_KIND_MBR ){
+	if( is_mbr( p ) ){
 		item_t	*eq;
 		bool_t	*flg_abl;
 
@@ -1926,7 +1949,7 @@ long	get_armor_def( chr_t *p, abl_kind_t abl )
 		return armor_def;
 	}
 
-	if( p->kind == CHR_KIND_MBR ){
+	if( is_mbr( p ) ){
 		item_t	*eq;
 		long	i;
 
@@ -1979,7 +2002,7 @@ long	get_ac( chr_t *p )
 	ac = 0;
 	armor_ac = 0;
 
-	if( p->kind == CHR_KIND_MBR ){
+	if( is_mbr( p ) ){
 		item_t	*eq;
 		long	i;
 
@@ -2012,7 +2035,16 @@ long	get_ac( chr_t *p )
 
 	armor_ac += p->fx_data.armor_ac;
 
-	ac = AC_AVE_N * armor_ac / _100_PERCENT;
+#if	FLG_ITEM_ADD_RATE
+
+	ac += AC_AVE_N * armor_ac / _100_PERCENT;
+
+#else	/* FLG_ITEM_ADD_RATE */
+
+	ac = AC_AVE_N;
+	ac = ac * armor_ac / _100_PERCENT;
+
+#endif	/* FLG_ITEM_ADD_RATE */
 
 	if( ac < 1 )
 		ac = 1;
@@ -2077,13 +2109,12 @@ rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack )
 
 	wpn_crtcl += p->fx_data.wpn_crtcl;
 
-#ifdef	FLG_ITEM_ADD_RATE
+#if	FLG_ITEM_ADD_RATE
 
-	crtcl += WPN_CRTCL_FIT_AVE_N * wpn_crtcl / _100_PERCENT;
+	crtcl += WPN_CRTCL_AVE_N * wpn_crtcl / _100_PERCENT;
 
 #else	/* FLG_ITEM_ADD_RATE */
 
-	crtcl += WPN_CRTCL_FIT_AVE_N;
 	crtcl = crtcl * wpn_crtcl / _100_PERCENT;
 
 #endif	/* FLG_ITEM_ADD_RATE */
@@ -2110,7 +2141,7 @@ rate_t	get_armor_crtcl( chr_t *p )
 	crtcl = 0;
 	armor_crtcl = 0;
 
-	if( p->kind == CHR_KIND_MBR ){
+	if( is_mbr( p ) ){
 		item_t	*eq;
 		long	i;
 
@@ -2143,7 +2174,17 @@ rate_t	get_armor_crtcl( chr_t *p )
 
 	armor_crtcl += p->fx_data.armor_crtcl;
 
-	crtcl = ARMOR_CRTCL_AVE_N * armor_crtcl / _100_PERCENT;
+#if	FLG_ITEM_ADD_RATE
+
+	crtcl += ARMOR_CRTCL_AVE_N * armor_crtcl / _100_PERCENT;
+
+#else	/* FLG_ITEM_ADD_RATE */
+
+	crtcl = ARMOR_CRTCL_AVE_N;
+	crtcl = crtcl * armor_crtcl / _100_PERCENT;
+
+#endif	/* FLG_ITEM_ADD_RATE */
+
 
 	if( crtcl < 1 )
 		crtcl = 1;
@@ -2176,15 +2217,15 @@ bool_t	chk_ninja_crtcl( chr_t *o_p, chr_t *d_p )
 	o_abl_m = ABL_KIND_NIN;
 	o_abl_s = ABL_KIND_DEX;
 	o_val = 0;
-	o_val += calc_lev_to_val( get_lev( o_p, o_abl_m ), o_abl_m );
-	o_val += calc_lev_to_val( get_lev( o_p, o_abl_s ), o_abl_s );
+	o_val += calc_abl_to_val( o_p, o_abl_m );
+	o_val += calc_abl_to_val( o_p, o_abl_s );
 	o_val /= 2;
 
 	d_abl_m = get_specialist_abl( d_p );
 	d_abl_s = ABL_KIND_DEX;
 	d_val = 0;
-	d_val += calc_lev_to_val( get_lev( d_p, d_abl_m ), d_abl_m );
-	d_val += calc_lev_to_val( get_lev( d_p, d_abl_s ), d_abl_s );
+	d_val += calc_abl_to_val( d_p, d_abl_m );
+	d_val += calc_abl_to_val( d_p, d_abl_s );
 	d_val /= 2;
 
 	if( get_lev( o_p, ABL_KIND_NIN ) <= 0 )
@@ -2201,6 +2242,114 @@ bool_t	chk_ninja_crtcl( chr_t *o_p, chr_t *d_p )
 		return FALSE;
 }
 
+/***************************************************************
+* ϤνͤΨѴ
+* long n : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_hit( long n )
+{
+	return( n * ADD_HIT_RATE );
+}
+
+/***************************************************************
+* ¦ΥƥνͤΨѴ
+* long n : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_wpn_crtcl( long n )
+{
+	return( n * ADD_WPN_CRTCL_RATE );
+}
+
+/***************************************************************
+* ᡼νͤΨѴ
+* long n : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_dam( long n )
+{
+	return( n * ADD_DAM_RATE );
+}
+
+/***************************************************************
+* ξ狼åơ᡼νΨ֤
+* mbr_t *mbr : С
+* item_t *wpn : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_dam_two_handed_wpn( mbr_t *mbr, item_t *wpn )
+{
+	item_t	*eq;
+
+	if( mbr == NULL )
+		return _100_PERCENT;
+	if( !is_mbr( mbr ) )
+		return _100_PERCENT;
+	if( wpn == NULL )
+		return _100_PERCENT;
+	if( wpn->kind != ITEM_KIND_WPN )
+		return _100_PERCENT;
+
+	do {
+		if( chk_flg( wpn->tab.wpn->flg,
+				FLG_WPN_TAB_TWO_HANDED ) ){
+			break;
+		}
+		if( chk_flg( wpn->tab.wpn->flg,
+				FLG_WPN_TAB_CAN_TWO_HANDED ) ){
+			break;
+		}
+
+		return _100_PERCENT;
+	} while( 0 );
+
+	eq = get_mbr_item_asgn_equip( mbr );
+	if( eq == NULL )
+		return _100_PERCENT;
+	if( eq[EQUIP_KIND_SHIELD].kind != ITEM_KIND_NULL )
+		return _100_PERCENT;
+
+	return TWO_HANDED_WPN_ADD_DAM_RATE;
+}
+
+/***************************************************************
+* ɸϤνͤΨѴ
+* long n : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_def( long n )
+{
+	return( n * ADD_DEF_RATE );
+}
+
+/***************************************************************
+* ɸ¦ΥƥνͤΨѴ
+* long n : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_armor_crtcl( long n )
+{
+	return( n * ADD_ARMOR_CRTCL_RATE );
+}
+
+/***************************************************************
+* ޡ饹νͤΨѴ
+* long n : 
+* return : Ψ
+***************************************************************/
+
+rate_t	add_ac( long n )
+{
+	return( n * ADD_AC_RATE );
+}
+
 /***************************************************************
 * ˤ᡼׻
 * chr_t *p : 饯
@@ -2220,8 +2369,8 @@ long	get_dam_stick( chr_t *p )
 	abl_sub = abl_main;
 
 	dam = 0;
-	dam += calc_lev_to_val( get_lev( p, abl_main ), abl_main );
-	dam += calc_lev_to_val( get_lev( p, abl_sub ), abl_sub );
+	dam += calc_abl_to_val( p, abl_main );
+	dam += calc_abl_to_val( p, abl_sub );
 	dam /= 2;
 
 	dam = dam * DAM_STICK_RATE / _100_PERCENT;
@@ -2249,8 +2398,8 @@ long	get_dam_spell( chr_t *p, abl_kind_t abl_main, abl_kind_t abl_sub )
 		return 1;
 
 	dam = 0;
-	dam += calc_lev_to_val( get_lev( p, abl_main ), abl_main );
-	dam += calc_lev_to_val( get_lev( p, abl_sub ), abl_sub );
+	dam += calc_abl_to_val( p, abl_main );
+	dam += calc_abl_to_val( p, abl_sub );
 	dam /= 2;
 
 	dam = dam * DAM_SPELL_RATE / _100_PERCENT;
@@ -2297,9 +2446,9 @@ rate_t	get_chr_throw_range_rate( chr_t *o_p, chr_t *d_p )
 	rate_t	rate;
 
 	if( o_p == NULL )
-		return 0;
+		return( (rate_t)0 );
 	if( d_p == NULL )
-		return 0;
+		return( (rate_t)0 );
 
 	rate = get_throw_range_rate(
 			o_p->trgt.true_x, o_p->trgt.true_y,
@@ -2323,9 +2472,9 @@ rate_t	get_throw_range_rate( long x1, long y1, long x2, long y2 )
 	rate_t	rate;
 
 	if( !clip_pos( x1, y1 ) )
-		return 0;
+		return( (rate_t)0 );
 	if( !clip_pos( x2, y2 ) )
-		return 0;
+		return( (rate_t)0 );
 
 	dx = labs( x1 - x2 );
 	dy = labs( y1 - y2 );
