@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.17 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.18 2007/05/11 00:42:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -338,6 +338,18 @@ auto_mark_cond_t	g_am_cond_trans_tab[] = {
 
 	/* ƱʪäƤ */
 	AUTO_MARK_COND_OWN,
+
+	/* 1  HP ξʤ */
+	AUTO_MARK_COND_HP_MIN,
+
+	/* 1  HP ¿ */
+	AUTO_MARK_COND_HP_MAX,
+
+	/* 1  MP ξʤ */
+	AUTO_MARK_COND_MP_MIN,
+
+	/* 1  MP ¿ */
+	AUTO_MARK_COND_MP_MAX,
 };
 
 /***************************************************************
