@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-ver.h,v 1.33 2007/05/16 09:37:18 bowkenken Exp $
+* $Id: gfile-ver.h,v 1.34 2007/12/14 23:24:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_VER_H
@@ -39,6 +39,7 @@
 #define	STR_GAME_CONF_HEAD	"# L&L - configure file version "
 #define	STR_GAME_DATA_HEAD	"# L&L - data file version "
 #define	STR_GAME_REPLAY_HEAD	"# L&L - replay file version "
+#define	STR_GRAPH_CONF_HEAD	"# L&L - graphic configure - version "
 
 /***************************************************************
 * ե ~/.lnl/usr/lnl.conf
@@ -149,4 +150,15 @@
 #define	GAME_DATA_VER_MNR	2
 #define	GAME_DATA_VER_PAT	3
 
+/***************************************************************
+* եå
+* ~/.lnl/xlnl/graph/???/xlnl-conf.txt
+* History:
+* 1.0.0
+***************************************************************/
+
+#define	GRAPH_CONF_VER_MJR	1
+#define	GRAPH_CONF_VER_MNR	0
+#define	GRAPH_CONF_VER_PAT	0
+
 #endif	/* GFILE_VER_H */
