@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.93 2007/06/07 02:09:16 bowkenken Exp $
+* $Id: gmain.c,v 1.99 2007/12/24 16:36:55 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -60,12 +60,12 @@
 * ѿ
 ***************************************************************/
 
-long	flg_term;
+static long	flg_term;
 
 #if	HAVE_TERMIOS_H
-struct termios	pre_tbuf;
+static struct termios	pre_tbuf;
 #elif	HAVE_TERMIO_H
-struct termio	pre_tbuf;
+static struct termio	pre_tbuf;
 #endif
 
 /***************************************************************
@@ -73,13 +73,14 @@ struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUD:S:l:k:e:s:p:md:Vh"
+#define	STR_OPT	"GCUT:D:S:l:k:e:s:p:md:Vh"
 
 #if	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
 	{ "gui",           no_argument,       NULL, 'G' },
 	{ "cui",           no_argument,       NULL, 'C' },
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
+	{ "text-mode",     required_argument, NULL, 'T' },
 	{ "sel-graph-dir", required_argument, NULL, 'D' },
 	{ "map-scale",     required_argument, NULL, 'S' },
 	{ "language",      required_argument, NULL, 'l' },
@@ -105,6 +106,8 @@ char	str_usage[] = {
 	"  -G, --gui                set GUI mode\n"
 	"  -C, --cui                set CUI mode\n"
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
+	"  -T, --text-mode=POINT    set TEXT mode:\n"
+	"                             point of font, ON or OFF\n"
 	"  -D, --sel-graph-dir=DIR  select graphic directory:\n"
 	"                             graphic directory\n"
 	"  -S, --map-scale=N        set scale of map character:\n"
@@ -112,17 +115,17 @@ char	str_usage[] = {
 	"  -l, --language=LANGUAGE  set language:\n"
 	"                             language\n"
 	"  -k, --clear-key-buf=FLAG clear key buffer:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -e, --echo-key=FLAG      echo key:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -s, --use-curses=FLAG    use curses library:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 	"  -m, --measure-clock      measure frame rate\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -d, --debug=FLAG         set debug mode:\n"
-	"                             ON, OFF\n"
+	"                             ON or OFF\n"
 #endif
 	"  -V, --version            display version and exit\n"
 	"  -h, --help               display this help and exit\n"
@@ -144,6 +147,10 @@ void	init_arg( void )
 
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
+
+	g_flg_text_mode = FALSE;
+	g_text_mode_point = 0;
+
 	g_graph_scale_rate = _100_PERCENT;
 	g_gui_key_kind = GUI_KEY_KIND_CONSOLE;
 
@@ -220,11 +227,21 @@ void	chk_arg( int argc, char **argv )
 			g_flg_cui = TRUE;
 			g_flg_gui = TRUE;
 			break;
-		case 'g':
+		case 'T':
+			if( chk_opt_flg( optarg, &g_flg_text_mode,
+					FALSE ) ){
+				g_text_mode_point = 0;
+			} else {
+				g_flg_text_mode = TRUE;
+				chk_opt_num( optarg, &g_text_mode_point,
+						TRUE );
+			}
+			break;
+		case 'D':
 			set_str_dir_sel_graph( optarg );
 			break;
 		case 'S':
-			g_graph_scale_rate = strtol( optarg, NULL, 0 );
+			chk_opt_num( optarg, &g_graph_scale_rate, TRUE );
 			break;
 		case 'l':
 			if( g_language != NULL )
@@ -238,30 +255,30 @@ void	chk_arg( int argc, char **argv )
 			break;
 		case 'k':
 			g_flg_clr_key_buf_arg_overwrite = TRUE;
-			g_flg_clr_key_buf_arg = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_clr_key_buf_arg, TRUE );
 			break;
 		case 'e':
-			g_flg_echo_key = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_echo_key, TRUE );
 			break;
 		case 's':
-			g_flg_use_curs = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_use_curs, TRUE );
 			break;
 		case 'p':
-			g_flg_use_keypad = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_use_keypad, TRUE );
 			break;
 		case 'm':
 			g_flg_measure_clk_tck = TRUE;
 			break;
 		case 'd':
-			g_flg_debug = chk_opt_flg( optarg );
+			chk_opt_flg( optarg, &g_flg_debug, TRUE );
 			break;
 		case 'V':
 			version( stdout );
-			exit( EXIT_SUCCESS );
+			gexit( EXIT_SUCCESS );
 			break;
 		case 'h':
 			usage( stdout );
-			exit( EXIT_SUCCESS );
+			gexit( EXIT_SUCCESS );
 			break;
 		case '\0':
 			break;
@@ -269,30 +286,78 @@ void	chk_arg( int argc, char **argv )
 		case ':':
 		default:
 			usage( stderr );
-			exit( EXIT_FAILURE );
+			gexit( EXIT_FAILURE );
 			break;
 		}
 	}
 
 	if( (argc - optind) > 0 ){
 		usage( stderr );
-		exit( EXIT_FAILURE );
+		gexit( EXIT_FAILURE );
 	}
 }
 
+/***************************************************************
+* ͤΰå
+* const char *optarg : ץʸ
+* long *pn : ֤ͤ
+* bool_t flg_err_exit : 顼ǽλ뤫?
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	chk_opt_num(
+	const char *optarg, long *pn, bool_t flg_err_exit
+)
+{
+	do {
+		if( optarg == NULL )
+			break;
+		if( pn == NULL )
+			break;
+		if( !isdigit( optarg[0] ) )
+			break;
+
+		/* ͤꤵ줿 */
+
+		*pn = strtol( optarg, NULL, 0 );
+
+		return TRUE;
+		break;
+	} while( 0 );
+
+	/* 顼 */
+
+	if( flg_err_exit ){
+		usage( stderr );
+		gexit( EXIT_FAILURE );
+	}
+
+	return FALSE;
+}
+
 /***************************************************************
 * Υ󡿥դΥե饰å
 * const char *optarg : ץʸ
-* return : ե饰?
+* bool_t *flg : ե饰󤫤ɤ֤
+* bool_t flg_err_exit : 顼ǽλ뤫?
+* return : 顼̵ä?
 ***************************************************************/
 
-bool_t	chk_opt_flg( const char *optarg )
+bool_t	chk_opt_flg(
+	const char *optarg, bool_t *flg, bool_t flg_err_exit
+)
 {
 	static char	str[OPT_ARG_MAX_LEN + 1];
 	long	i;
 
-	if( optarg == NULL )
+	if( optarg == NULL ){
+		if( flg_err_exit ){
+			usage( stderr );
+			gexit( EXIT_FAILURE );
+		}
+
 		return FALSE;
+	}
 
 	for( i = 0; i < OPT_ARG_MAX_LEN; i++ ){
 		if( optarg[i] == '\0' )
@@ -301,6 +366,7 @@ bool_t	chk_opt_flg( const char *optarg )
 	}
 	str[i] = '\0';
 
+	*flg = TRUE;
 	if( strcmp( str, "ON" ) == 0 )
 		return TRUE;
 	if( strcmp( str, "TRUE" ) == 0 )
@@ -312,19 +378,22 @@ bool_t	chk_opt_flg( const char *optarg )
 	if( strcmp( str, "1" ) == 0 )
 		return TRUE;
 
+	*flg = FALSE;
 	if( strcmp( str, "OFF" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "FALSE" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "NIL" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "NO" ) == 0 )
-		return FALSE;
+		return TRUE;
 	if( strcmp( str, "0" ) == 0 )
-		return FALSE;
+		return TRUE;
 
-	usage( stderr );
-	exit( EXIT_FAILURE );
+	if( flg_err_exit ){
+		usage( stderr );
+		gexit( EXIT_FAILURE );
+	}
 
 	return FALSE;
 }
@@ -370,7 +439,9 @@ void	init_game( void )
 	init_signal();
 	init_scrn();
 
-	srandm( time( NULL ) );
+	srandm( (long)time( NULL ) );
+
+	init_scene();
 	init_turn();
 
 	init_msg();
@@ -432,6 +503,9 @@ void	init_game( void )
 
 void	game_main( void )
 {
+	chk_scroll( TRUE );
+	redraw_all();
+
 	if( !g_flg_debug ){
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
@@ -455,7 +529,7 @@ void	exit_game( long code )
 {
 	close_game( code );
 
-	exit( code );
+	gexit( code );
 }
 
 /***************************************************************
@@ -465,8 +539,9 @@ void	exit_game( long code )
 
 void	close_game( long code )
 {
-	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
+	close_item();
 
+	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
 	reset_scrn();
 
 	fflush( stdout );
@@ -545,7 +620,7 @@ void	init_signal( void )
 	signal( SIGSEGV, signal_handler );
 	signal( SIGABRT, signal_handler );
 	signal( SIGTERM, signal_handler );
-#else	/* D_X68K */
+#else
 	signal( SIGHUP, signal_handler );
 	signal( SIGINT, signal_handler );
 	signal( SIGKILL, signal_handler );
@@ -553,7 +628,7 @@ void	init_signal( void )
 	signal( SIGSEGV, signal_handler );
 	signal( SIGABRT, signal_handler );
 	signal( SIGTERM, signal_handler );
-#endif	/* D_X68K */
+#endif
 }
 
 /***************************************************************
@@ -565,7 +640,7 @@ void	signal_handler( int sig )
 {
 	reset_scrn();
 
-	exit( EXIT_FAILURE );
+	exit_game( EXIT_FAILURE );
 }
 
 /***************************************************************
