@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.30 2007/06/07 16:38:53 bowkenken Exp $
+* $Id: imenu.c,v 1.37 2007/12/15 08:18:28 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -103,7 +103,27 @@ char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt )
 
 /**/
 
-bool_t	chk_continue_exec_mode( void )
+bool_t	chk_continue_exec_mode( long *c )
+{
+	static bool_t	flg_pre_null = TRUE;
+
+	if( !get_continue_exec_mode() )
+		return FALSE;
+
+	if( flg_pre_null ){
+		*c = '.';
+		flg_pre_null = FALSE;
+	} else {
+		*c = '|';
+		flg_pre_null = TRUE;
+	}
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	get_continue_exec_mode( void )
 {
 	return g_flg_continue_exec_mode;
 }
@@ -558,17 +578,19 @@ char	*menu_sel_mbr_data( void )
 	long	sel_mbr_n = get_sel_mbr_n();
 	long	n;
 	long	page_n;
+	data_n_t	data_n;
 
 	if( sel_mbr_n <= -1 )
 		return STR_MENU_ERR;
 
 	n = sel_mbr_n;
 	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
 
 	while( 1 ){
 		long	add;
 
-		add = menu_show_mbr_data( mbr[n], &page_n );
+		add = menu_show_mbr_data( mbr[n], &page_n, &data_n );
 		if( add == 0 )
 			break;
 
@@ -580,27 +602,30 @@ char	*menu_sel_mbr_data( void )
 
 /**/
 
-long	menu_show_mbr_data( mbr_t *mbr, long *page_n )
+long	menu_show_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n )
 {
-	return menu_mbr_data( mbr, page_n, MBR_DATA_EDIT_KIND_SHOW );
+	return menu_mbr_data( mbr, page_n, data_n,
+			MBR_DATA_EDIT_KIND_SHOW );
 }
 
 /**/
 
-long	menu_edit_mbr_data( mbr_t *mbr, long *page_n )
+long	menu_edit_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n )
 {
-	return menu_mbr_data( mbr, page_n, MBR_DATA_EDIT_KIND_EDIT );
+	return menu_mbr_data( mbr, page_n, data_n,
+			MBR_DATA_EDIT_KIND_EDIT );
 }
 
 /**/
 
 long	menu_mbr_data(
-	mbr_t *org_p, long *page_n,
+	mbr_t *org_p, long *page_n, data_n_t *data_n,
 	mbr_data_edit_kind_t edit_kind
 )
 {
 	mbr_t	dst_mbr, *mbr_p;
-	data_n_t	n, prev_n;
+	data_n_t	prev_n;
+	long	mbr_dn, page_dn;
 
 	if( org_p == NULL )
 		return 0;
@@ -608,8 +633,8 @@ long	menu_mbr_data(
 	mbr_p = &dst_mbr;
 	*mbr_p = *org_p;
 
-	n = next_mbr_data( *page_n, DATA_N_NEXT_PAGE, +-0, edit_kind );
-	prev_n = n;
+	*data_n = next_mbr_data( *page_n, *data_n, +-0, edit_kind );
+	prev_n = *data_n;
 
 	draw_mbr_data_all( org_p, mbr_p, *page_n );
 
@@ -617,8 +642,10 @@ long	menu_mbr_data(
 		bool_t	flg_sel, flg_cancel;
 
 		draw_mbr_data( org_p, mbr_p, prev_n, FALSE );
-		draw_mbr_data( org_p, mbr_p, n, TRUE );
-		prev_n = n;
+		draw_mbr_data( org_p, mbr_p, *data_n, TRUE );
+		prev_n = *data_n;
+		mbr_dn = 0;
+		page_dn = 0;
 
 		flg_sel = FALSE;
 		flg_cancel = FALSE;
@@ -638,34 +665,64 @@ long	menu_mbr_data(
 			else
 				flg_sel = TRUE;
 			break;
+		case '/':
+		case 'z':
+			page_dn -= 1;
+			break;
+		case '*':
+		case 'x':
+			page_dn += 1;
+			break;
+		case '-':
+		case 'c':
+			mbr_dn -= 1;
+			break;
+		case '+':
+		case 'v':
+			mbr_dn += 1;
+			break;
 		case CASE_CRSR_LEFT:
-			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
-				return -1;
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+			if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+				page_dn -= 1;
+			else
+				mbr_dn -= 1;
 			break;
 		case CASE_CRSR_RIGHT:
-			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
-				return +1;
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+			if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+				page_dn += 1;
+			else
+				mbr_dn += 1;
 			break;
 		case CASE_CRSR_DOWN:
-			n = next_mbr_data( *page_n, n, +1, edit_kind );
+			*data_n = next_mbr_data( *page_n, *data_n,
+					+1, edit_kind );
 			break;
 		case CASE_CRSR_UP:
-			n = next_mbr_data( *page_n, n, -1, edit_kind );
+			*data_n = next_mbr_data( *page_n, *data_n,
+					-1, edit_kind );
 			break;
 		default:
 			break;
 		}
 
 		if( flg_sel ){
-			draw_mbr_data( org_p, mbr_p, n, FALSE );
-			*page_n += exec_menu_edit_mbr_data( mbr_p, n );
+			draw_mbr_data( org_p, mbr_p, *data_n, FALSE );
+			exec_menu_edit_mbr_data(
+					mbr_p, *data_n,
+					&mbr_dn, &page_dn );
+		}
+		if( mbr_dn != 0 ){
+			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
+				return mbr_dn;
+			draw_mbr_data_all( org_p, mbr_p, *page_n );
+		}
+		if( page_dn != 0 ){
+			*page_n += page_dn;
 			*page_n += MBR_DATA_PAGE_MAX_N;
 			*page_n %= MBR_DATA_PAGE_MAX_N;
-			n = next_mbr_data( *page_n, n,
+			*data_n = next_mbr_data( *page_n, *data_n,
 					+-0, edit_kind );
-			prev_n = n;
+			prev_n = *data_n;
 			if( edit_kind == MBR_DATA_EDIT_KIND_NEW ){
 				new_mbr_reset( mbr_p );
 				*org_p = *mbr_p;
@@ -684,7 +741,9 @@ long	menu_mbr_data(
 
 /**/
 
-long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n )
+void	exec_menu_edit_mbr_data(
+	mbr_t *mbr, data_n_t n, long *mbr_dn, long *page_dn
+)
 {
 	item_t	*item_head, *item;
 	equip_kind_t	eq_k;
@@ -765,14 +824,20 @@ long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n )
 		break;
 
 	case DATA_N_PREV_PAGE:
-		return -1;
+		if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+			*mbr_dn -= 1;
+		else
+			*page_dn -= 1;
+		return;
 	case DATA_N_NEXT_PAGE:
-		return +1;
+		if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+			*mbr_dn += 1;
+		else
+			*page_dn += 1;
+		return;
 	default:
 		break;
 	}
-
-	return +-0;
 }
 
 /**/
@@ -1344,6 +1409,83 @@ void	jump_crsr( long dx, long dy )
 
 /**/
 
+char	*cb_menu_crsr_scroll( menu_t **pp, menu_t **dflt )
+{
+	switch( (long)((*pp)->arg) ){
+	case 1:
+		crsr_scroll( -1, +1 );
+		break;
+	case 2:
+		crsr_scroll( 0, +1 );
+		break;
+	case 3:
+		crsr_scroll( +1, +1 );
+		break;
+	case 4:
+		crsr_scroll( -1, 0 );
+		break;
+	case 6:
+		crsr_scroll( +1, 0 );
+		break;
+	case 7:
+		crsr_scroll( -1, -1 );
+		break;
+	case 8:
+		crsr_scroll( 0, -1 );
+		break;
+	case 9:
+		crsr_scroll( +1, -1 );
+		break;
+	default:
+		return STR_MENU_ERR;
+	}
+	chk_scroll( TRUE );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+void	crsr_scroll( long dx, long dy )
+{
+	pos_t	*crsr = get_crsr();
+	pos_t	*draw;
+
+	draw = get_map_draw_pos();
+
+	/* X */
+
+	draw->x += dx;
+	crsr->x += dx;
+
+	if( draw->x < 0 )
+		draw->x = 0;
+	if( draw->x > MAP_MAX_X - WIN_MAP_WIDTH )
+		draw->x = MAP_MAX_X - WIN_MAP_WIDTH;
+
+	if( crsr->x < 0 )
+		crsr->x = 0;
+	if( crsr->x > MAP_MAX_X - 1 )
+		crsr->x = MAP_MAX_X - 1;
+
+	/* Y */
+
+	draw->y += dy;
+	crsr->y += dy;
+
+	if( draw->y < 0 )
+		draw->y = 0;
+	if( draw->y > MAP_MAX_Y - WIN_MAP_HEIGHT )
+		draw->y = MAP_MAX_Y - WIN_MAP_HEIGHT;
+
+	if( crsr->y < 0 )
+		crsr->y = 0;
+	if( crsr->y > MAP_MAX_Y - 1 )
+		crsr->y = MAP_MAX_Y - 1;
+
+	redraw_map();
+}
+
 char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt )
 {
 	mbr_t	*mbr;
@@ -1460,6 +1602,7 @@ void	scroll_center( void )
 	draw = get_map_draw_pos();
 
 	/* X */
+
 	if( crsr->x < 0 )
 		crsr->x = 0;
 	if( crsr->x > MAP_MAX_X - 1 )
@@ -1472,6 +1615,7 @@ void	scroll_center( void )
 		draw->x = MAP_MAX_X - WIN_MAP_WIDTH;
 
 	/* Y */
+
 	if( crsr->y < 0 )
 		crsr->y = 0;
 	if( crsr->y > MAP_MAX_Y - 1 )
@@ -3553,9 +3697,51 @@ char	*cb_menu_func( menu_t **pp, menu_t **dflt )
 char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt )
 {
 	long	n;
+	char	*str;
+	char	str_ret_m[4 + 1];
+	char	str_ret_j[4 + 1];
+
+	str_ret_m[0] = 'M' - '@';
+	str_ret_m[1] = '\0';
+	str_ret_j[0] = 'J' - '@';
+	str_ret_j[1] = '\0';
 
 	n = (long)((*pp)->arg);
-	set_key_buf_str( get_func( n ) );
+	str = get_func( n );
+
+	/* ˥塼μ¹ */
+
+	do {
+		if( get_flg_chk_menu() )
+			break;
+
+		if( strcmp( str, "\n" ) == 0 )
+			break;
+		if( strcmp( str, "^M" ) == 0 )
+			break;
+		if( strcmp( str, "^J" ) == 0 )
+			break;
+		if( strcmp( str, str_ret_m ) == 0 )
+			break;
+		if( strcmp( str, str_ret_j ) == 0 )
+			break;
+
+		if( strcmp( str, "\033" ) == 0 )
+			break;
+		if( strcmp( str, "^[" ) == 0 )
+			break;
+		if( strcmp( str, "0" ) == 0 )
+			break;
+
+		if( strcmp( str, "." ) == 0 ){
+			str = "0";
+			break;
+		}
+
+		return NULL;
+	} while( 0 );
+
+	set_key_buf_str( str );
 
 	return NULL;
 }
@@ -4113,6 +4299,32 @@ char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_system( menu_t **pp, menu_t **dflt )
+{
+	set_menu_dflt_misc( *pp );
+
+	if( g_flg_debug )
+		clr_flg_menu( *pp, "wizard", FLG_MENU_HIDDEN );
+	else
+		set_flg_menu( *pp, "wizard", FLG_MENU_HIDDEN );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_command( menu_t **pp, menu_t **dflt )
+{
+	char	cmd[MENU_COMMAND_MAX_LEN + 1];
+
+	gets_line( MENU_COMMAND_KEY_STR, cmd, MENU_COMMAND_MAX_LEN );
+
+	return exec_menu( get_ls_menu_main(),
+			get_menu_dflt_main(), cmd );
+}
+
+/**/
+
 char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt )
 {
 	long	n;
@@ -4283,20 +4495,6 @@ char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_system( menu_t **pp, menu_t **dflt )
-{
-	set_menu_dflt_misc( *pp );
-
-	if( g_flg_debug )
-		clr_flg_menu( *pp, "wizard", FLG_MENU_HIDDEN );
-	else
-		set_flg_menu( *pp, "wizard", FLG_MENU_HIDDEN );
-
-	return NULL;
-}
-
-/**/
-
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt )
 {
 	if( g_flg_debug )
