@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.39 2007/03/31 21:16:03 bowkenken Exp $
+* $Id: misc.c,v 1.40 2007/12/05 13:20:39 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -60,11 +60,14 @@ char	*fmt_gold( gold_t gold )
 
 char	*fmt_num( long n )
 {
-	long	i;
+	long	sg;
 	static char	str[32 + 1];
 	long	max_len;
 	char	*head;
 	char	str_tmp[4 + 1];
+	long	i;
+
+	sg = sgn_l( n );
 
 	max_len = (sizeof( str ) / sizeof( char )) - 1;
 
@@ -91,7 +94,7 @@ char	*fmt_num( long n )
 		}
 	}
 
-	if( n <= -1 ){
+	if( sg <= -1 ){
 		head--;
 		*head = '-';
 	}
@@ -99,6 +102,43 @@ char	*fmt_num( long n )
 	return head;
 }
 
+/***************************************************************
+* ޡեޥåʸͤѴ
+* long n : ޡեޥåʸ
+* return : 
+***************************************************************/
+
+long	un_fmt_num( const char *s )
+{
+	long	sg, n;
+	long	i;
+
+	sg = +1;
+	n = 0;
+
+	for( i = 0; i < LOOP_MAX_100; i++, s++ ){
+		if( *s == '\0' )
+			break;
+		if( *s == ',' )
+			continue;
+		if( *s == '+' )
+			continue;
+		if( *s == '-' ){
+			sg = -sg;
+			continue;
+		}
+		if( !isdigit( *s ) )
+			break;
+
+		n *= 10;
+		n += *s - '0';
+	}
+
+	n *= sg;
+
+	return n;
+}
+
 /***************************************************************
 * long ͤ +- ֤
 * long n : 
