@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.23 2007/06/08 07:08:44 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.24 2007/11/02 18:23:49 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -443,7 +443,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/hint",
 		"<Item>",
-		'I',
+		'H',
 		"?",
 		N_MSG_MENU_MAP_HINT, "",
 		cb_menu_show_map_hint, NULL,
@@ -1061,6 +1061,15 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 /* replay end */
+	{
+		"/misc/system/command",
+		"<Item>",
+		'C',
+		MENU_COMMAND_KEY_STR,
+		N_MSG_MENU_COMMAND, "",
+		cb_menu_command, NULL,
+		FLG_NULL,
+	},
 /* wizard begin */
 	{
 		"/misc/system/wizard",
@@ -1138,7 +1147,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/system/output map file",
 		"<OpenWinItem>",
-		'O',
+		'M',
 		"",
 		N_MSG_MENU_OUT_MAP_FILE, "",
 		cb_menu_out_map_file, NULL,
@@ -1147,7 +1156,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/system/shell",
 		"<OpenWinItem>",
-		'H',
+		'S',
 		"!",
 		N_MSG_MENU_SHELL, "",
 		cb_menu_shell, NULL,
