@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.29 2007/06/07 02:09:16 bowkenken Exp $
+* $Id: mmenu.c,v 1.31 2007/10/19 21:32:33 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -465,6 +465,8 @@ char	*cb_menu_exec( menu_t **pp, menu_t **dflt )
 	inc_turn();
 	exec_all_phase();
 
+	call_pcg_dun_draw_turn();
+
 	return NULL;
 }
 
@@ -2672,7 +2674,7 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	if( chk_flg_or( mbr->stat,
@@ -2819,7 +2821,7 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	if( chk_flg_or( mbr->stat,
