@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.185 2007/05/11 00:42:16 bowkenken Exp $
+* $Id: mnstr.c,v 1.188 2007/06/11 08:25:36 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -276,6 +276,8 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->mnstr_tab = NULL;
 	mnstr->mnstr_tab_org = NULL;
 
+	mnstr->flg_pet = FALSE;
+
 	mnstr->work.flg = FLG_NULL;
 	mnstr->work.caught = 0;
 	mnstr->work.catch_chr = NULL;
@@ -469,6 +471,7 @@ mnstr_t	*make_mnstr_alloc(
 	p->mnstr_kind_org = mnstr_kind;
 	p->mnstr_tab = tab;
 	p->mnstr_tab_org = tab;
+	p->flg_pet = FALSE;
 
 	p->work.flg = FLG_NULL;
 	p->work.flg &= ~(FLG_WORK_FIND_MBR);
@@ -1486,10 +1489,16 @@ void	garbage_collection_all_mnstr( void )
 		if( pp == head )
 			break;
 
-		if( chk_flg_or( pp->stat,
+		if( !chk_flg_or( pp->stat,
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
-			ins_ls_mnstr( &mnstr_free, pp );
+			continue;
 		}
+		if( is_pet( pp ) )
+			continue;
+
+		/* ꡼ */
+
+		ins_ls_mnstr( &mnstr_free, pp );
 	}
 }
 
