@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.32 2007/03/19 06:49:04 bowkenken Exp $
+* $Id: msg.c,v 1.34 2007/11/08 13:13:37 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -77,7 +77,7 @@ static bool_t	g_flg_lang_ls_priority;
 
 /* Υǡ */
 typedef struct {
-	char	*id;
+	char	*id_n;
 	char	*name;
 	lang_kind_t	kind;
 } lang_t;
@@ -185,10 +185,10 @@ void	init_msg( void )
 	g_lang_kind = LANG_KIND_MAX_N;
 	lang_tab_kind = 0;
 	for( k = 0; k < LANG_TAB_MAX_N; k++ ){
-		if( lang_tab[k].id == NULL )
+		if( lang_tab[k].id_n == NULL )
 			break;
 
-		if( strcmp( lang, lang_tab[k].id ) == 0 ){
+		if( strcmp( lang, lang_tab[k].id_n ) == 0 ){
 			g_lang_kind = lang_tab[k].kind;
 			lang_tab_kind = k;
 			break;
@@ -202,11 +202,11 @@ void	init_msg( void )
 		print_err( STR_ERR_LANG, lang );
 		print_err( STR_S, STR_SUPPORT_LANG );
 		for( k = 0; k < LANG_TAB_MAX_N; k++ ){
-			if( lang_tab[k].id == NULL )
+			if( lang_tab[k].id_n == NULL )
 				break;
 
 			fprintf( stderr, STR_SUPPORT_LANG_LIST,
-					lang_tab[k].id );
+					lang_tab[k].id_n );
 		}
 		fprintf( stderr, "\n" );
 		exit_game( EXIT_FAILURE );
@@ -228,7 +228,8 @@ void	init_msg( void )
 			/* åƤ */
 			s = all_lang_msg[g_lang_kind][m].s;
 			print_err( STR_ERR_REDEFINED_MSG,
-					lang_tab[lang_tab_kind].id, m, s );
+					lang_tab[lang_tab_kind].id_n,
+					m, s );
 			flg_exit = TRUE;
 		}
 
@@ -243,7 +244,8 @@ void	init_msg( void )
 		if( !flg_msg_def[m] ){
 			/* åƤʤ */
 			print_err( STR_ERR_NOT_DEFINED_MSG,
-					lang_tab[lang_tab_kind].id, m );
+					lang_tab[lang_tab_kind].id_n,
+					m );
 			flg_exit = TRUE;
 		}
 	}
@@ -322,15 +324,15 @@ char	*get_lang_id_next( void )
 	long	k;
 
 	for( k = 0; k < LANG_TAB_MAX_N; k++ ){
-		if( lang_tab[k].id == NULL )
+		if( lang_tab[k].id_n == NULL )
 			break;
 
 		if( lang_tab[k].kind == g_lang_kind_next ){
-			return( lang_tab[k].id );
+			return( lang_tab[k].id_n );
 		}
 	}
 
-	return( lang_tab[0].id );
+	return( lang_tab[0].id_n );
 }
 
 /***************************************************************
@@ -372,7 +374,7 @@ char	*get_lang_kind_name( lang_kind_t kind )
 		return MSG_NULL;
 
 	for( i = 0; i < LANG_TAB_MAX_N; i++ ){
-		if( lang_tab[i].id == NULL )
+		if( lang_tab[i].id_n == NULL )
 			break;
 
 		if( lang_tab[i].kind == kind ){
@@ -394,10 +396,10 @@ lang_kind_t	trans_lang_id_to_kind( char *id )
 	long	k;
 
 	for( k = 0; k < LANG_TAB_MAX_N; k++ ){
-		if( lang_tab[k].id == NULL )
+		if( lang_tab[k].id_n == NULL )
 			break;
 
-		if( strcmp( id, lang_tab[k].id ) == 0 ){
+		if( strcmp( id, lang_tab[k].id_n ) == 0 ){
 			return( lang_tab[k].kind );
 		}
 	}
@@ -505,7 +507,9 @@ long	str_len_draw_japanese_utf_8( const char *s )
 		len += 2;
 		s++;
 		for( i = 1; i < skip_n; i++ ){
-			if( *s == '\0' ){
+			c = (unsigned char)*s;
+
+			if( c == '\0' ){
 				s--;
 				break;
 			}
