@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.196 2007/06/07 22:58:14 bowkenken Exp $
+* $Id: party.c,v 1.198 2007/11/06 03:17:59 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -212,7 +212,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_FIGHTER, 0 );
-	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.gif",
+	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_DWARF;
@@ -220,7 +220,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
-	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.gif",
+	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HALF_ELF;
@@ -228,7 +228,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
-	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.png",
+	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -236,7 +236,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
-	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.png",
+	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_VIVID;
@@ -244,7 +244,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
-	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.png",
+	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_ELF;
@@ -252,7 +252,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
-	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.png",
+	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -260,7 +260,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
-	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.png",
+	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -268,7 +268,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
-	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.gif",
+	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.bmp",
 			FILE_NAME_MAX_LEN );
 
 	/* item */
@@ -427,7 +427,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_NINJA, 0 );
-	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.gif",
+	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_DWARF;
@@ -435,7 +435,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
-	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.gif",
+	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HALF_ELF;
@@ -443,7 +443,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
-	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.png",
+	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -451,7 +451,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
-	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.png",
+	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_VIVID;
@@ -459,7 +459,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
-	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.png",
+	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_ELF;
@@ -467,7 +467,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
-	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.png",
+	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -475,7 +475,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
-	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.png",
+	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -483,7 +483,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
-	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.gif",
+	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.bmp",
 			FILE_NAME_MAX_LEN );
 
 	/* ã */
@@ -911,7 +911,7 @@ item_t	*init_mbr_item(
 
 	if( mbr == NULL )
 		return NULL;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return NULL;
 
 	lev = -10;
@@ -1314,7 +1314,7 @@ bool_t	reset_mbr_resi( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	for( k = 0; k < RESI_KIND_MAX_N; k++ )
@@ -1641,7 +1641,7 @@ bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	if( !chk_flg( mbr->flg_chr, FLG_CHR_AUTO_FIGHT ) )
@@ -1672,7 +1672,7 @@ bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	if( !chk_flg( mbr->flg_chr, FLG_CHR_AUTO_DOOR ) )
@@ -1698,7 +1698,7 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 
 	if( mbr == NULL )
 		return;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return;
 
 	if( !flg_chk_game_over )
@@ -2819,7 +2819,7 @@ long	get_mbr_n( long x, long y )
 	dun = get_dun();
 
 	p = dun->map.chr_p[y][x];
-	if( (p != NULL) && (p->kind == CHR_KIND_MBR) )
+	if( (p != NULL) && is_mbr( p ) )
 		return( p->mbr_n );
 
 	pty = get_party();
