@@ -6,6 +6,7 @@ extern "C" {
 
 void	init_spell( void );
 void	init_spell_debug( void );
+void	init_spell_new_mbr( long ls_mbr_n );
 void	init_spell_dflt( void );
 void	init_spell_nin( void );
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt );
@@ -90,6 +91,9 @@ bool_t	chk_chr_learned_spell_nin(
 	bool_t flg_test
 );
 bool_t	chk_learn_spell_item( chr_t *chr, spell_kind_t kind );
+void	arrange_cast_tab( long trgt_ls_mbr_n, long d );
+void	remove_cast_tab( long trgt_ls_mbr_n );
+bool_t	copy_cast_tab( cast_tab_t dst[], cast_tab_t src[] );
 char	*get_spell_vfx_str( spell_kind_t spell_kind );
 cast_tab_t	*get_cast_tab( chr_t *chr, spell_kind_t kind );
 char	*get_spell_name( spell_kind_t kind );
