@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.164 2007/06/01 01:08:53 bowkenken Exp $
+* $Id: spell.c,v 1.167 2007/11/09 11:46:50 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -37,7 +37,10 @@
 
 /**/
 
-#define	CHK_SPELL_LEV_RATE	((rate_t)200)
+/* ξǵʳȤɤ? */
+#define	FLG_SPELL_SANCTUARY	TRUE
+
+#define	CHK_SPELL_LEV_RATE	((rate_t)100)
 #define	CHK_SPELL_LEV_RATE_BASE	((rate_t)90)
 
 #define	SPELL_PRICE_LEV_MUL	((rate_t)500)
@@ -1418,11 +1421,12 @@ void	chr_cast_spell_sub(
 		d_p = (chr_t *)NULL;
 	}
 
+#if	(! FLG_SPELL_SANCTUARY)
 	/* ξǤϵʳϤȤɤʤ */
 
 	if( tab->abl != ABL_KIND_PRI ){
 		if( chk_map_sanctuary( chr->x, chr->y ) ){
-			if( chr->kind == CHR_KIND_MBR ){
+			if( is_mbr( chr ) ){
 				curs_attrset_chr( chr, -1, FALSE );
 				print_msg( FLG_NULL,
 						MSG_FAIL_SPELL_SANCTUARY,
@@ -1435,6 +1439,7 @@ void	chr_cast_spell_sub(
 		if( chk_map_sanctuary( x, y ) )
 			return;
 	}
+#endif	/* ENABLE_SPELL_SANCTUARY */
 
 	/* ɸ˻̤äƤ뤫å */
 
@@ -1757,7 +1762,7 @@ void	chr_cast_spell_sub(
 			break;
 		if( is_pet( chr ) )
 			break;
-		if( ((chr_t *)p)->kind != CHR_KIND_MBR )
+		if( !is_mbr( (chr_t *)p ) )
 			break;
 		chr->work.flg_used_energy_drain = TRUE;
 
@@ -2100,10 +2105,8 @@ void	counter_magic(
 	if( p == NULL )
 		return;
 
-	if( (chr->kind != CHR_KIND_MBR)
-			&& (chr->kind != CHR_KIND_MNSTR) ){
+	if( !is_mbr( chr ) && !is_mnstr_or_pet( chr ) )
 		return;
-	}
 
 	fx = srch_fx( &(chr->fx), FX_KIND_COUNTER_MAGIC );
 	if( fx == NULL )
@@ -2111,7 +2114,7 @@ void	counter_magic(
 
 	switch( trgt_kind ){
 	case TRGT_KIND_MBR:
-		if( chr->kind == CHR_KIND_MBR )
+		if( is_mbr( chr ) )
 			return;
 		break;
 	case TRGT_KIND_MNSTR:
@@ -2159,8 +2162,8 @@ bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item )
 
 	rate = get_lev( o_p, o_abl ) - tab->lev;
 	rate += get_lev( o_p, o_sub_abl ) - tab->lev;
-	rate = rate * CHK_SPELL_LEV_RATE / _100_PERCENT;
 	rate /= 2;
+	rate = rate * CHK_SPELL_LEV_RATE / _100_PERCENT;
 	rate += CHK_SPELL_LEV_RATE_BASE;
 
 	/* ˤ뽤 */
@@ -2482,7 +2485,7 @@ bool_t	chk_bar_limit( chr_t *chr )
 	if( chr == NULL )
 		return FALSE;
 
-	if( chr->kind != CHR_KIND_MBR )
+	if( !is_mbr( chr ) )
 		return TRUE;
 
 	if( chk_bar_limit_lev( chr ) )
@@ -2508,7 +2511,7 @@ bool_t	chk_bar_limit_lev( chr_t *chr )
 	if( chr == NULL )
 		return FALSE;
 
-	if( chr->kind != CHR_KIND_MBR )
+	if( !is_mbr( chr ) )
 		return TRUE;
 
 	if( get_lev( chr, ABL_KIND_BAR ) < BAR_LIMIT_LEV )
@@ -2574,7 +2577,7 @@ bool_t	chk_chr_learned_spell( chr_t *chr, spell_kind_t kind )
 	if( chr == NULL )
 		return FALSE;
 
-	if( chr->kind != CHR_KIND_MBR )
+	if( !is_mbr( chr ) )
 		return TRUE;	/* FALSE ǤϤʤ */
 
 	cast_tab = get_cast_tab( chr, kind );
@@ -2593,7 +2596,7 @@ bool_t	set_chr_learned_spell( chr_t *chr, spell_kind_t kind, bool_t flg )
 	if( chr == NULL )
 		return FALSE;
 
-	if( chr->kind != CHR_KIND_MBR )
+	if( !is_mbr( chr ) )
 		return TRUE;	/* FALSE ǤϤʤ */
 
 	tab = get_cast_tab( chr, kind );
@@ -2642,7 +2645,7 @@ void	learn_spell_pri( chr_t *chr )
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ ){
 		spell_tab_t	*spell_tab;
 
-		if( chr->kind == CHR_KIND_MBR )
+		if( is_mbr( chr ) )
 			if( cast_tab[chr->ls_mbr_n][k].flg_cast )
 				continue;
 
@@ -2674,7 +2677,7 @@ void	learn_spell_sha( chr_t *chr )
 	for( k = SPELL_KIND_SHA_MIN_N + 1; k < SPELL_KIND_SHA_MAX_N; k++ ){
 		spell_tab_t	*spell_tab;
 
-		if( chr->kind == CHR_KIND_MBR )
+		if( is_mbr( chr ) )
 			if( cast_tab[chr->ls_mbr_n][k].flg_cast )
 				continue;
 
@@ -2706,7 +2709,7 @@ void	learn_spell_bar( chr_t *chr )
 	for( k = SPELL_KIND_BAR_MIN_N + 1; k < SPELL_KIND_BAR_MAX_N; k++ ){
 		spell_tab_t	*spell_tab;
 
-		if( chr->kind == CHR_KIND_MBR )
+		if( is_mbr( chr ) )
 			if( cast_tab[chr->ls_mbr_n][k].flg_cast )
 				continue;
 
@@ -2743,7 +2746,7 @@ bool_t	chk_chr_learned_spell_nin(
 	if( chr == NULL )
 		return FALSE;
 
-	if( chr->kind != CHR_KIND_MBR )
+	if( !is_mbr( chr ) )
 		return TRUE;	/* FALSE ǤϤʤ */
 
 	if( kind <= SPELL_KIND_NIN_MIN_N )
@@ -2847,7 +2850,7 @@ bool_t	chk_learn_spell_item( chr_t *chr, spell_kind_t kind )
 	if( chr == NULL )
 		return FALSE;
 
-	if( chr->kind != CHR_KIND_MBR )
+	if( !is_mbr( chr ) )
 		return TRUE;	/* FALSE ǤϤʤ */
 
 	item = NULL;
