@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.20 2007/05/16 09:37:19 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.21 2007/06/07 02:09:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -1537,7 +1537,7 @@ menu_t	ls_menu_bar[] = {
 		'L',
 		"",
 		N_MSG_MENU_BAR_LOAD, "",
-		cb_menu_bar_load, NULL,
+		cb_menu_load_bar, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1546,7 +1546,7 @@ menu_t	ls_menu_bar[] = {
 		'S',
 		"",
 		N_MSG_MENU_BAR_SAVE, "",
-		cb_menu_bar_save, NULL,
+		cb_menu_save_bar, NULL,
 		FLG_NULL,
 	},
 	{
