@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.127 2007/06/07 02:09:16 bowkenken Exp $
+* $Id: town.c,v 1.128 2007/06/11 08:25:36 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -1714,21 +1714,22 @@ void	take_bath( chr_t *chr )
 
 	print_msg( FLG_NULL, MSG_TAKE_BATH, chr->name );
 
-	if( chr->kind == CHR_KIND_MBR ){
+	if( !is_mbr( chr ) )
+		return;
+
+	print_words( chr->name, chr->sex.cur,
+			MSG_WORDS_TAKE_BATH_FAMALE,
+			MSG_WORDS_TAKE_BATH_MALE );
+
+	/* ԴˤΤ줿 */
+
+	if( rate_randm( MBR_IS_MOLESTED_RATE ) ){
+		print_msg( FLG_NULL, MSG_CHR_IS_MOLESTED,
+				chr->name );
+
 		print_words( chr->name, chr->sex.cur,
-				MSG_WORDS_TAKE_BATH_FAMALE,
-				MSG_WORDS_TAKE_BATH_MALE );
-
-		/* ԴˤΤ줿 */
-
-		if( rate_randm( MBR_IS_MOLESTED_RATE ) ){
-			print_msg( FLG_NULL, MSG_CHR_IS_MOLESTED,
-					chr->name );
-
-			print_words( chr->name, chr->sex.cur,
-					MSG_WORDS_CHR_IS_MOLESTED_FAMALE,
-					MSG_WORDS_CHR_IS_MOLESTED_MALE );
-		}
+				MSG_WORDS_CHR_IS_MOLESTED_FAMALE,
+				MSG_WORDS_CHR_IS_MOLESTED_MALE );
 	}
 }
 
@@ -2999,7 +3000,7 @@ long	get_discount_queue_n( chr_t *chr )
 
 long	get_discount_queue_max_n( chr_t *chr )
 {
-	if( chr->kind == CHR_KIND_MBR )
+	if( is_mbr( chr ) )
 		return DISCOUNT_QUEUE_MAX_N;
 	else
 		return DISCOUNT_QUEUE_MAX_N - MBR_MAX_N;
@@ -3070,7 +3071,7 @@ void	inc_discount_queue( chr_t *chr )
 	g_discount_queue.chr[g_discount_queue.n] = chr;
 	g_discount_queue.n++;
 
-	if( chr->kind == CHR_KIND_MBR )
+	if( is_mbr( chr ) )
 		print_msg( FLG_NULL, MSG_INC_DISCOUNT_QUEUE, chr->name );
 }
 
