@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.h,v 1.33 2007/03/19 09:11:43 bowkenken Exp $
+* $Id: trap.h,v 1.35 2007/11/06 03:17:59 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TRAP_H
@@ -42,7 +42,7 @@
 * ǥХåѥå
 ***************************************************************/
 
-/* 1 ˤ櫤̤ˤĤ */
+/* 1 ˤ櫤̤ˤĤ(ǥХå) */
 
 #if	0
 # ifndef	D_TEST_TRAP
@@ -50,14 +50,6 @@
 # endif
 #endif
 
-/* 1 ˤ櫤Ĥ */
-
-#if	0
-# ifndef	D_TEST_TRAP_KIND
-#  define	D_TEST_TRAP_KIND	TRAP_KIND_SLEEP
-# endif
-#endif
-
 #ifdef	D_TEST_TRAP
 # define	TRAP_AVE_N	512
 # define	TRAP_MAX_N	1024
@@ -131,8 +123,10 @@ typedef struct trap_t {
 	long	lev;
 	/* 񤷤 */
 	long	difficulty;
-	/* Ĵ٤Ƥ뤫 */
+	/* Ĵ٤Ƥ뤫? */
 	bool_t	flg_chked;
+	/* 櫤濴ؤкɸ */
+	bool_t	cx, cy;
 
 	/* ǡơ֥ */
 	trap_tab_t	*tab;
