@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.49 2007/03/10 19:42:20 bowkenken Exp $
+* $Id: ver.h,v 1.52 2007/12/24 17:38:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -50,7 +50,7 @@
 #define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"
 
 #define	STR_TITLE_3	" "
-#define	STR_HANDLE_3	"and kokusi(yujyu)"
+#define	STR_HANDLE_3	"kokusi(yujyu) hiyo and URARA"
 
 #define	STR_TITLE_THANKS	"Special Thanks"
 #define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"
@@ -58,16 +58,18 @@
 #define	STR_FMT_COPYRIGHT	\
 		"--------------------------------" \
 		"--------------------------------\n" \
-		"%s : version %s\n" \
+		"%s : version %s  \n" \
 		"Copyright (c) %s-%s %s All rights reserved.\n" \
-		"\n" \
-		"URL   : %s\n" \
-		"E-mail: %s\n" \
-		"\n" \
-		"%20s  %s\n" \
-		"%20s  %s\n" \
-		"%20s  %s\n" \
-		"%20s  %s\n" \
+		"                                " \
+		"                                \n" \
+		"URL   : %-56s\n" \
+		"E-mail: %-56s\n" \
+		"                                " \
+		"                                \n" \
+		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		""
